@@ -45,7 +45,6 @@
 #include "../mymoney/mymoneystatement.h"
 
 class MyMoneyFileTransaction;
-class MyMoneyStatementReaderPrivate;
 class QStringList;
 
 /**
@@ -83,12 +82,20 @@ public:
     * @param create flag if this feature should be turned on (@p true)
     *               or turned off (@p false)
     */
-  void setAutoCreatePayee(const bool create);
+  void setAutoCreatePayee(bool create);
+  void setAskPayeeCategory(bool ask);
 
   const MyMoneyAccount& account() const { return m_account; };
 
   void setProgressCallback(void(*callback)(int, int, const QString&));
 
+  /**
+   * Returns true in case any transaction has been added to the engine
+   * during the import of the statement. Only returns useful result
+   * after import() has been called.
+   */
+  bool anyTransactionAdded(void) const;
+
 private:
   /**
     * This method is used to update the progress information. It
@@ -98,8 +105,9 @@ private:
     */
   void signalProgress(int current, int total, const QString& = "");
 
-  void processTransactionEntry(const MyMoneyStatement::Transaction&);
-  void processSecurityEntry(const MyMoneyStatement::Security&);
+  void processTransactionEntry(const MyMoneyStatement::Transaction& t_in);
+  void processSecurityEntry(const MyMoneyStatement::Security& s_in);
+  void processPriceEntry(const MyMoneyStatement::Price& p_in);
 
   enum SelectCreateMode {
     Create = 0,
@@ -118,17 +126,6 @@ private:
     */
   bool selectOrCreateAccount(const SelectCreateMode mode, MyMoneyAccount& account);
 
-  /**
-    * This method looks up the @p searchname account by name and returns its id
-    * if it was found.  If it was not found, it creates a new income account using
-    * @p searchname as a name, and returns the id if the newly created account
-    *
-    * @param searchname The name of the account to find or create
-    * @return QCString id of the found or created account
-    */
-  static const QCString findOrCreateIncomeAccount(const QString& searchname);
-  static const QCString findOrCreateExpenseAccount(const QString& searchname);
-
 signals:
   /**
     * This signal will be emitted when the import is finished.
@@ -136,12 +133,16 @@ signals:
   void importFinished(void);
 
 private:
-  MyMoneyStatementReaderPrivate* d;
+  /// \internal d-pointer class.
+  class Private;
+  /// \internal d-pointer instance.
+  Private* const d;
   MyMoneyAccount          m_account;
   QStringList             m_dontAskAgain;
   bool                    m_skipAccount;
   bool                    m_userAbort;
   bool                    m_autoCreatePayee;
+  bool                    m_askPayeeCategory;
   MyMoneyFileTransaction* m_ft;
 
   void (*m_progressCallback)(int, int, const QString&);
