@@ -27,6 +27,7 @@
 // KDE Headers
 
 #include <kio/netaccess.h>
+#include <kio/scheduler.h>
 #include <kurl.h>
 #include <klocale.h>
 #include <kdebug.h>
@@ -35,6 +36,7 @@
 #include <kglobal.h>
 #include <kstandarddirs.h>
 #include <kcalendarsystem.h>
+#include <ktempfile.h>
 
 // ----------------------------------------------------------------------------
 // Project Headers
@@ -47,6 +49,9 @@
 QString WebPriceQuote::m_financeQuoteScriptPath;
 QStringList WebPriceQuote::m_financeQuoteSources;
 
+QString * WebPriceQuote::lastErrorMsg;
+int WebPriceQuote::lastErrorCode = 0;
+
 WebPriceQuote::WebPriceQuote( QObject* _parent, const char* _name ):
   QObject( _parent, _name )
 {
@@ -156,7 +161,7 @@ bool WebPriceQuote::launchNative( const QString& _symbol, const QString& _id, co
     emit status(QString("Fetching URL %1...").arg(url.prettyURL()));
 
     QString tmpFile;
-    if( KIO::NetAccess::download( url, tmpFile, NULL ) )
+    if( download( url, tmpFile, NULL ) )
     {
       kdDebug(2) << "Downloaded " << tmpFile << endl;
       QFile f(tmpFile);
@@ -171,7 +176,7 @@ bool WebPriceQuote::launchNative( const QString& _symbol, const QString& _id, co
       {
         slotParseQuote(QString());
       }
-      KIO::NetAccess::removeTempFile( tmpFile );
+      removeTempFile( tmpFile );
     }
     else
     {
@@ -182,6 +187,75 @@ bool WebPriceQuote::launchNative( const QString& _symbol, const QString& _id, co
   return result;
 }
 
+void WebPriceQuote::removeTempFile(const QString& tmpFile)
+{
+  if(tmpFile == m_tmpFile) {
+    unlink(tmpFile);
+    m_tmpFile = QString();
+  }
+}
+
+bool WebPriceQuote::download(const KURL& u, QString & target, QWidget* window)
+{
+  m_tmpFile = QString();
+
+  // the following code taken and adapted from KIO::NetAccess::download()
+  if (target.isEmpty())
+  {
+    KTempFile tmpFile;
+    target = tmpFile.name();
+    m_tmpFile = target;
+  }
+
+  KURL dest;
+  dest.setPath( target );
+
+
+  // the following code taken and adapted from KIO::NetAccess::filecopyInternal()
+  bJobOK = true; // success unless further error occurs
+
+  KIO::Scheduler::checkSlaveOnHold(true);
+  KIO::Job * job = KIO::file_copy( u, dest, -1, true, false, false );
+  job->setWindow (window);
+  job->addMetaData("cache", "reload");  // bypass cache
+  connect( job, SIGNAL( result (KIO::Job *) ),
+           this, SLOT( slotResult (KIO::Job *) ) );
+
+  enter_loop();
+  return bJobOK;
+
+}
+
+// The following parts are copied and adjusted from KIO::NetAccess
+
+// If a troll sees this, he kills me
+void qt_enter_modal( QWidget *widget );
+void qt_leave_modal( QWidget *widget );
+
+void WebPriceQuote::enter_loop(void)
+{
+  QWidget dummy(0,0,WType_Dialog | WShowModal);
+  dummy.setFocusPolicy( QWidget::NoFocus );
+  qt_enter_modal(&dummy);
+  qApp->enter_loop();
+  qt_leave_modal(&dummy);
+}
+
+void WebPriceQuote::slotResult( KIO::Job * job )
+{
+  lastErrorCode = job->error();
+  bJobOK = !job->error();
+  if ( !bJobOK )
+  {
+    if ( !lastErrorMsg )
+      lastErrorMsg = new QString;
+    *lastErrorMsg = job->errorString();
+  }
+
+  qApp->exit_loop();
+}
+// The above parts are copied and adjusted from KIO::NetAccess
+
 bool WebPriceQuote::launchFinanceQuote ( const QString& _symbol, const QString& _id,
                                const QString& _sourcename ) {
   bool result = true;
@@ -233,18 +307,20 @@ void WebPriceQuote::slotParseQuote(const QString& _quotedata)
 
   if ( ! quotedata.isEmpty() )
   {
-    //
-    // First, remove extranous non-data elements
-    //
+    if(!m_source.m_skipStripping) {
+      //
+      // First, remove extranous non-data elements
+      //
 
-    // HTML tags
-    quotedata.remove(QRegExp("<[^>]*>"));
+      // HTML tags
+      quotedata.remove(QRegExp("<[^>]*>"));
 
-    // &...;'s
-    quotedata.replace(QRegExp("&\\w+;")," ");
+      // &...;'s
+      quotedata.replace(QRegExp("&\\w+;")," ");
 
-    // Extra white space
-    quotedata = quotedata.simplifyWhiteSpace();
+      // Extra white space
+      quotedata = quotedata.simplifyWhiteSpace();
+    }
 
 #if KMM_DEBUG
     // Enable to get a look at the data coming back from the source after it's stripped
@@ -349,13 +425,17 @@ QMap<QString,WebPriceQuoteSource> WebPriceQuote::defaultQuoteSources(void)
     "%m %d %y" // dateformat
   );
 
+  // 2009-08-20 Yahoo UK has no quotes and has comma separators
+  // sl1d1 format for Yahoo UK doesn't seem to give a date ever
+  // sl1d3 gives US locale time (9:99pm) and date (mm/dd/yyyy)
   result["Yahoo UK"] = WebPriceQuoteSource("Yahoo UK",
-    "http://uk.finance.yahoo.com/d/quotes.csv?s=%1&f=sl1d1",
-    "\"([^,\"]*)\",.*",  // symbolregexp
-    "[^,]*,([^,]*),.*", // priceregexp
-    "[^,]*,[^,]*,\"([^\"]*)\"", // dateregexp
-    "%m %d %y" // dateformat
+    "http://uk.finance.yahoo.com/d/quotes.csv?s=%1&f=sl1d3",
+    "^([^,]*),.*",  // symbolregexp
+    "^[^,]*,([^,]*),.*", // priceregexp
+    "^[^,]*,[^,]*,(.*)", // dateregexp
+    "%m/%d/%y" // dateformat
   );
+
   // sl1d1 format for Yahoo France doesn't seem to give a date ever
   // sl1d3 gives us time (99h99) and date
   result["Yahoo France"] = WebPriceQuoteSource("Yahoo France",
@@ -389,7 +469,7 @@ QMap<QString,WebPriceQuoteSource> WebPriceQuote::defaultQuoteSources(void)
     "\\).(\\d+\\D+\\d+\\D+\\d+)", // dateregexp (doesn't work; date in chart
     "%d.%m.%y" // dateformat
   );
-  
+
   result["boerseonline"] = WebPriceQuoteSource("boerseonline",
     "http://www.boerse-online.de/tools/boerse/einzelkurs_kurse.htm?&s=%1",
     QString(),  // symbolregexp
@@ -408,7 +488,7 @@ QMap<QString,WebPriceQuoteSource> WebPriceQuote::defaultQuoteSources(void)
     ", (\\d+\\D+\\d+\\D+\\d+)", // dateregexp
     "%d %m %y" // dateformat
   );
-  
+
   // This quote source provided by Peter Lord
   // The trading symbol will normally be the SEDOL (see wikipedia) but
   // the flexibility presently (1/2008) in the code will allow use of
@@ -420,7 +500,7 @@ QMap<QString,WebPriceQuoteSource> WebPriceQuote::defaultQuoteSources(void)
       "Valuation date:[\\ ]*(\\d+/\\d+/\\d+)", // date regexp
       "%d/%m/%y" // date format
   );
-  
+
   // This quote source provided by Danny Scott
   result["Yahoo Canada"] = WebPriceQuoteSource("Yahoo Canada",
       "http://ca.finance.yahoo.com/q?s=%1",
@@ -429,7 +509,7 @@ QMap<QString,WebPriceQuoteSource> WebPriceQuote::defaultQuoteSources(void)
       "day, (.\\D+\\d+\\D+\\d+)", // date regexp
       "%m %d %y" // date format
   );
-  
+
   // (tf2k) The "mpid" is I think the market place id. In this case five
   // stands for Hamburg.
   //
@@ -463,7 +543,7 @@ QMap<QString,WebPriceQuoteSource> WebPriceQuote::defaultQuoteSources(void)
     "(\\d{4,4}-\\d{2,2}-\\d{2,2})", // date regexp
     "%y %m %d"                   // date format
   );
-  
+
   // The following price quote is for getting prices of different funds
   // at OMX Baltic market.
   result["OMX Baltic funds"] = WebPriceQuoteSource("OMX Baltic funds",
@@ -474,6 +554,38 @@ QMap<QString,WebPriceQuoteSource> WebPriceQuote::defaultQuoteSources(void)
       "%d.%m.%y"   // dateformat
   );
 
+  // The following price quote was contributed by
+  // Peter Hargreaves <pete.h@pdh-online.info>
+  // The original posting can be found here:
+  // http://sourceforge.net/mailarchive/message.php?msg_name=200806060854.11682.pete.h%40pdh-online.info
+
+  // I have PEP and ISA accounts which I invest in Funds with Barclays
+  // Stockbrokers. They give me Fund data via Financial Express:
+  //
+  // https://webfund6.financialexpress.net/Clients/Barclays/default.aspx
+  //
+  // A typical Fund Factsheet is:
+  //
+  // https://webfund6.financialexpress.net/Clients/Barclays/search_factsheet_summary.aspx?code=0585239
+  //
+  // On the Factsheet to identify the fund you can see ISIN Code GB0005852396.
+  // In the url, this code is shortened by loosing the first four and last
+  // characters.
+  //
+  // Update:
+  //
+  // Nick Elliot has contributed a modified regular expression to cope with values presented
+  // in pounds as well as those presented in pence. The source can be found here:
+  // http://forum.kde.org/update-stock-and-currency-prices-t-32049.html
+
+  result["Financial Express"] = WebPriceQuoteSource("Financial Express",
+       "https://webfund6.financialexpress.net/Clients/Barclays/search_factsheet_summary.aspx?code=%1",
+       "ISIN Code[^G]*(GB..........).*",  // symbolregexp
+       "Current Market Information[^0-9]*([0-9,\\.]+).*", // priceregexp
+       "Price Date[^0-9]*(../../....).*", // dateregexp
+       "%d/%m/%y"                         // dateformat
+  );
+
   return result;
 }
 
@@ -578,6 +690,7 @@ WebPriceQuoteSource::WebPriceQuoteSource(const QString& name)
   m_dateformat = kconfig->readEntry("DateFormatRegex","%m %d %y");
   m_price = kconfig->readEntry("PriceRegex");
   m_url = kconfig->readEntry("URL");
+  m_skipStripping = kconfig->readBoolEntry("SkipStripping", false);
 }
 
 void WebPriceQuoteSource::write(void) const
@@ -589,6 +702,10 @@ void WebPriceQuoteSource::write(void) const
   kconfig->writeEntry("DateRegex", m_date);
   kconfig->writeEntry("DateFormatRegex", m_dateformat);
   kconfig->writeEntry("SymbolRegex", m_sym);
+  if(m_skipStripping)
+    kconfig->writeEntry("SkipStripping", m_skipStripping);
+  else
+    kconfig->deleteEntry("SkipStripping");
 }
 
 void WebPriceQuoteSource::rename(const QString& name)
