@@ -33,6 +33,7 @@
 #include <kpushbutton.h>
 #include <kstdguiitem.h>
 #include <klineedit.h>
+#include <knuminput.h>
 
 // ----------------------------------------------------------------------------
 // Project Includes
@@ -50,7 +51,7 @@
 #include "keditscheduledlg.h"
 #include "../kmymoney2.h"
 
-class KEditScheduleDlgPrivate {
+class KEditScheduleDlg::Private {
 public:
   MyMoneySchedule                m_schedule;
   KMyMoneyRegister::Transaction* m_item;
@@ -61,7 +62,7 @@ public:
 
 KEditScheduleDlg::KEditScheduleDlg(const MyMoneySchedule& schedule, QWidget *parent, const char *name) :
   KEditScheduleDlgDecl(parent, name, true),
-  d(new KEditScheduleDlgPrivate)
+  d(new Private)
 {
   d->m_schedule = schedule;
   d->m_editor = 0;
@@ -98,10 +99,11 @@ KEditScheduleDlg::KEditScheduleDlg(const MyMoneySchedule& schedule, QWidget *par
   // setup widget contents
   m_nameEdit->setText(d->m_schedule.name());
 
-  m_frequencyEdit->setCurrentItem(d->m_schedule.occurence());
+  m_frequencyEdit->setCurrentItem(d->m_schedule.occurencePeriod());
   if(m_frequencyEdit->currentItem() == -1)
     m_frequencyEdit->setCurrentItem(MyMoneySchedule::OCCUR_MONTHLY);
   slotFrequencyChanged(m_frequencyEdit->currentItem());
+  m_frequencyNoEdit->setValue(d->m_schedule.occurenceMultiplier());
 
   // load option widgets
   m_paymentMethodEdit->insertItem(i18n("Direct deposit"), MyMoneySchedule::STYPE_DIRECTDEPOSIT);
@@ -134,20 +136,26 @@ KEditScheduleDlg::KEditScheduleDlg(const MyMoneySchedule& schedule, QWidget *par
 
   m_endOptionsFrame->setEnabled(d->m_schedule.willEnd());
   if(d->m_schedule.willEnd()) {
-    m_RemainingEdit->setText(QString::number(d->m_schedule.transactionsRemaining()));
+    m_RemainingEdit->setValue(d->m_schedule.transactionsRemaining());
     m_FinalPaymentEdit->setDate(d->m_schedule.endDate());
   }
 
-  connect(m_RemainingEdit, SIGNAL(textChanged(const QString&)),
-    this, SLOT(slotRemainingChanged(const QString&)));
+  connect(m_RemainingEdit, SIGNAL(valueChanged(int)),
+    this, SLOT(slotRemainingChanged(int)));
   connect(m_FinalPaymentEdit, SIGNAL(dateChanged(const QDate&)),
     this, SLOT(slotEndDateChanged(const QDate&)));
   connect(m_frequencyEdit, SIGNAL(itemSelected(int)),
     this, SLOT(slotFrequencyChanged(int)));
+  connect(m_frequencyNoEdit, SIGNAL(valueChanged(int)),
+    this, SLOT(slotOccurenceMultiplierChanged(int)));
   connect(buttonHelp, SIGNAL(clicked()), this, SLOT(slotShowHelp()));
 
   // force the initial height to be as small as possible
   QTimer::singleShot(0, this, SLOT(slotSetupSize()));
+
+  // we just hide the variation field for now and enable the logic
+  // once we have a respective member in the MyMoneySchedule object
+  m_variation->hide();
 }
 
 KEditScheduleDlg::~KEditScheduleDlg()
@@ -168,7 +176,7 @@ TransactionEditor* KEditScheduleDlg::startEdit(void)
   // check that we use the same transaction commodity in all selected transactions
   // if not, we need to update this in the editor's list. The user can also bail out
   // of this operation which means that we have to stop editing here.
-  if(editor) {
+  if(editor && !d->m_schedule.account().id().isEmpty()) {
     if(!editor->fixTransactionCommodity(d->m_schedule.account())) {
       // if the user wants to quit, we need to destroy the editor
       // and bail out
@@ -184,7 +192,7 @@ TransactionEditor* KEditScheduleDlg::startEdit(void)
 
     connect(MyMoneyFile::instance(), SIGNAL(dataChanged()), editor, SLOT(slotReloadEditWidgets()));
     // connect(editor, SIGNAL(finishEdit(const KMyMoneyRegister::SelectedTransactions&)), this, SLOT(slotLeaveEditMode(const KMyMoneyRegister::SelectedTransactions&)));
-    connect(editor, SIGNAL(createPayee(const QString&, QCString&)), kmymoney2, SLOT(slotPayeeNew(const QString&, QCString&)));
+    connect(editor, SIGNAL(createPayee(const QString&, QString&)), kmymoney2, SLOT(slotPayeeNew(const QString&, QString&)));
     connect(editor, SIGNAL(createCategory(MyMoneyAccount&, const MyMoneyAccount&)), kmymoney2, SLOT(slotCategoryNew(MyMoneyAccount&, const MyMoneyAccount&)));
     connect(editor, SIGNAL(createSecurity(MyMoneyAccount&, const MyMoneyAccount&)), kmymoney2, SLOT(slotInvestmentNew(MyMoneyAccount&, const MyMoneyAccount&)));
     connect(MyMoneyFile::instance(), SIGNAL(dataChanged()), editor, SLOT(slotReloadEditWidgets()));
@@ -244,6 +252,7 @@ TransactionEditor* KEditScheduleDlg::startEdit(void)
     // don't forget our three buttons and additional widgets
     d->m_tabOrderWidgets.append(m_weekendOptionEdit);
     d->m_tabOrderWidgets.append(m_estimateEdit);
+    d->m_tabOrderWidgets.append(m_variation);
     d->m_tabOrderWidgets.append(m_autoEnterEdit);
     d->m_tabOrderWidgets.append(m_endSeriesEdit);
     d->m_tabOrderWidgets.append(m_RemainingEdit);
@@ -253,6 +262,7 @@ TransactionEditor* KEditScheduleDlg::startEdit(void)
     d->m_tabOrderWidgets.append(buttonCancel);
     d->m_tabOrderWidgets.append(buttonHelp);
     d->m_tabOrderWidgets.append(m_nameEdit);
+    d->m_tabOrderWidgets.append(m_frequencyNoEdit);
     d->m_tabOrderWidgets.append(m_frequencyEdit);
     d->m_tabOrderWidgets.append(m_paymentMethodEdit);
     d->m_tabOrderWidgets.append(m_form);
@@ -264,6 +274,12 @@ TransactionEditor* KEditScheduleDlg::startEdit(void)
       w->installEventFilter(editor);
     }
 
+    // connect the postdate modification signal to our update routine
+    kMyMoneyDateInput* dateEdit = dynamic_cast<kMyMoneyDateInput*>(editor->haveWidget("postdate"));
+    if(dateEdit)
+      connect(dateEdit, SIGNAL(dateChanged(const QDate&)), this, SLOT(slotPostDateChanged(const QDate&)));
+
+
     m_nameEdit->setFocus();
 
     // add the required fields to the mandatory group
@@ -305,12 +321,14 @@ void KEditScheduleDlg::accept(void)
 const MyMoneySchedule& KEditScheduleDlg::schedule(void) const
 {
   if(d->m_editor) {
-    if(d->m_schedule.nextDueDate() != transaction().postDate())
-      d->m_schedule.setNextDueDate(transaction().postDate());
-    d->m_schedule.setTransaction(transaction());
+    MyMoneyTransaction t = transaction();
+    if(d->m_schedule.nextDueDate() != t.postDate())
+        d->m_schedule.setNextDueDate(t.postDate());
+    d->m_schedule.setTransaction(t);
     d->m_schedule.setName(m_nameEdit->text());
     d->m_schedule.setFixed(!m_estimateEdit->isChecked());
-    d->m_schedule.setOccurence(static_cast<MyMoneySchedule::occurenceE>(m_frequencyEdit->currentItem()));
+    d->m_schedule.setOccurencePeriod(static_cast<MyMoneySchedule::occurenceE>(m_frequencyEdit->currentItem()));
+    d->m_schedule.setOccurenceMultiplier( m_frequencyNoEdit->value() );
 
     switch(m_weekendOptionEdit->currentItem())  {
       case 0:
@@ -359,7 +377,7 @@ MyMoneyTransaction KEditScheduleDlg::transaction(void) const
   MyMoneyTransaction t = d->m_schedule.transaction();
 
   if(d->m_editor) {
-    d->m_editor->createTransaction(t, d->m_schedule.transaction(), d->m_schedule.transaction().splits()[0], true);
+    d->m_editor->createTransaction(t, d->m_schedule.transaction(), d->m_schedule.transaction().splits()[0], false);
   }
 
   t.clearId();
@@ -434,16 +452,17 @@ void KEditScheduleDlg::resizeEvent(QResizeEvent* ev)
 }
 
 
-void KEditScheduleDlg::slotRemainingChanged(const QString& text)
+void KEditScheduleDlg::slotRemainingChanged(int value)
 {
   // Make sure the required fields are set
   kMyMoneyDateInput* dateEdit = dynamic_cast<kMyMoneyDateInput*>(d->m_editor->haveWidget("postdate"));
-  d->m_schedule.setStartDate(dateEdit->date());
-  d->m_schedule.setOccurence(static_cast<MyMoneySchedule::occurenceE>(m_frequencyEdit->currentItem()));
+  d->m_schedule.setNextDueDate(dateEdit->date());
+  d->m_schedule.setOccurencePeriod(static_cast<MyMoneySchedule::occurenceE>(m_frequencyEdit->currentItem()));
+  d->m_schedule.setOccurenceMultiplier(m_frequencyNoEdit->value());
 
-  if(d->m_schedule.transactionsRemaining() != text.toInt()) {
+  if(d->m_schedule.transactionsRemaining() != value) {
     m_FinalPaymentEdit->blockSignals(true);
-    m_FinalPaymentEdit->setDate(d->m_schedule.dateAfter(text.toInt()));
+    m_FinalPaymentEdit->setDate(d->m_schedule.dateAfter(value));
     m_FinalPaymentEdit->blockSignals(false);
   }
 }
@@ -452,15 +471,26 @@ void KEditScheduleDlg::slotEndDateChanged(const QDate& date)
 {
   // Make sure the required fields are set
   kMyMoneyDateInput* dateEdit = dynamic_cast<kMyMoneyDateInput*>(d->m_editor->haveWidget("postdate"));
-  d->m_schedule.setStartDate(dateEdit->date());
-  d->m_schedule.setOccurence(static_cast<MyMoneySchedule::occurenceE>(m_frequencyEdit->currentItem()));
+  d->m_schedule.setNextDueDate(dateEdit->date());
+  d->m_schedule.setOccurencePeriod(static_cast<MyMoneySchedule::occurenceE>(m_frequencyEdit->currentItem()));
+  d->m_schedule.setOccurenceMultiplier(m_frequencyNoEdit->value());
 
   if(d->m_schedule.endDate() != date) {
     d->m_schedule.setEndDate(date);
-    if(d->m_schedule.transactionsRemaining() != m_RemainingEdit->text().toInt())
-      m_RemainingEdit->blockSignals(true);
-      m_RemainingEdit->setText(QString::number(d->m_schedule.transactionsRemaining()));
-      m_RemainingEdit->blockSignals(false);
+    updateTransactionsRemaining();
+  }
+}
+
+void KEditScheduleDlg::slotPostDateChanged(const QDate& date)
+{
+  if(d->m_schedule.nextDueDate() != date) {
+    if (m_endOptionsFrame->isEnabled()) {
+      d->m_schedule.setNextDueDate(date);
+      d->m_schedule.setOccurenceMultiplier(m_frequencyNoEdit->value());
+      d->m_schedule.setOccurencePeriod(static_cast<MyMoneySchedule::occurenceE>(m_frequencyEdit->currentItem()));
+      d->m_schedule.setEndDate(m_FinalPaymentEdit->date());
+      updateTransactionsRemaining();
+    }
   }
 }
 
@@ -482,8 +512,65 @@ void KEditScheduleDlg::slotSetPaymentMethod(int item)
 void KEditScheduleDlg::slotFrequencyChanged(int item)
 {
   m_endSeriesEdit->setEnabled(item != MyMoneySchedule::OCCUR_ONCE);
-  if(m_endSeriesEdit->isChecked())
+  bool isEndSeries = m_endSeriesEdit->isChecked();
+  if(isEndSeries )
     m_endOptionsFrame->setEnabled(item != MyMoneySchedule::OCCUR_ONCE);
+  switch( item )
+  {
+    case MyMoneySchedule::OCCUR_DAILY:
+    case MyMoneySchedule::OCCUR_WEEKLY:
+    case MyMoneySchedule::OCCUR_EVERYHALFMONTH:
+    case MyMoneySchedule::OCCUR_MONTHLY:
+    case MyMoneySchedule::OCCUR_YEARLY:
+      // Supports Frequency Number
+      m_frequencyNoEdit->setEnabled(true);
+      break;
+    default:
+      // Multiplier is always 1
+      m_frequencyNoEdit->setEnabled(false);
+      m_frequencyNoEdit->setValue(1);
+      break;
+  }
+  if ( isEndSeries && ( item != MyMoneySchedule::OCCUR_ONCE ) )
+  {
+    // Changing the frequency changes the number
+    // of remaining transactions
+    kMyMoneyDateInput* dateEdit = dynamic_cast<kMyMoneyDateInput*>(d->m_editor->haveWidget("postdate"));
+    d->m_schedule.setNextDueDate(dateEdit->date());
+    d->m_schedule.setOccurenceMultiplier(m_frequencyNoEdit->value());
+    d->m_schedule.setOccurencePeriod(static_cast<MyMoneySchedule::occurenceE>(item));
+    d->m_schedule.setEndDate(m_FinalPaymentEdit->date());
+    updateTransactionsRemaining();
+  }
+}
+
+void KEditScheduleDlg::slotOccurenceMultiplierChanged(int multiplier)
+{
+  // Make sure the required fields are set
+  int oldOccurenceMultiplier = d->m_schedule.occurenceMultiplier();
+  if ( multiplier != oldOccurenceMultiplier )
+  {
+    if (m_endOptionsFrame->isEnabled())
+    {
+      kMyMoneyDateInput* dateEdit = dynamic_cast<kMyMoneyDateInput*>(d->m_editor->haveWidget("postdate"));
+      d->m_schedule.setNextDueDate(dateEdit->date());
+      d->m_schedule.setOccurenceMultiplier(multiplier);
+      d->m_schedule.setOccurencePeriod(static_cast<MyMoneySchedule::occurenceE>(m_frequencyEdit->currentItem()));
+      d->m_schedule.setEndDate(m_FinalPaymentEdit->date());
+      updateTransactionsRemaining();
+    }
+  }
+}
+
+void KEditScheduleDlg::updateTransactionsRemaining(void)
+{
+  int remain = d->m_schedule.transactionsRemaining();
+  if ( remain != m_RemainingEdit->value() )
+  {
+    m_RemainingEdit->blockSignals(true);
+    m_RemainingEdit->setValue(remain);
+    m_RemainingEdit->blockSignals(false);
+  }
 }
 
 void KEditScheduleDlg::slotShowHelp(void)
