@@ -72,10 +72,6 @@ public:
     */
   const QString profile(void) const { return m_profileComboBox->currentText(); };
 
-  /**
-    */
-  const bool autoCreatePayee(void) const { return m_payeeCreation->isChecked(); };
-
 protected slots:
   /** Called to let the user browse for a QIF file to import from. */
   void slotBrowse();
@@ -106,12 +102,6 @@ private:
     */
   void loadProfiles(const bool selectLast = false);
 
-  /**
-    * This method is used to load the available accounts into the
-    * combo box for selection.
-    */
-  void loadAccounts(void);
-
   /**
     * This method is used to load an account hierarchy into a string list
     *
@@ -119,7 +109,7 @@ private:
     * @param id Account id to add
     * @param leadIn constant leadin to be added in front of the account name
     */
-  void addCategories(QStringList& strList, const QCString& id, const QString& leadIn) const;
+  void addCategories(QStringList& strList, const QString& id, const QString& leadIn) const;
 
   void readConfig(void);
   void writeConfig(void);
