@@ -35,6 +35,7 @@
 #include <qradiobutton.h>
 #include <qtextedit.h>
 #include <qlayout.h>
+#include <qtabwidget.h>
 
 // ----------------------------------------------------------------------------
 // KDE Headers
@@ -46,7 +47,6 @@
 #include <klistview.h>
 #include <kstandarddirs.h>
 #include <kiconloader.h>
-#include <kguiitem.h>
 #include <kpushbutton.h>
 #include <kled.h>
 #include <kdebug.h>
@@ -79,10 +79,6 @@
 #include "../reports/kreportchartview.h"
 #include "../reports/pivottable.h"
 
-#ifdef USE_OFX_DIRECTCONNECT
-#include "../dialogs/konlinebankingsetupwizard.h"
-#endif
-
 // in KOffice version < 1.5 KDCHART_PROPSET_NORMAL_DATA was a static const
 // but in 1.5 this has been changed into a #define'd value. So we have to
 // make sure, we use the right one.
@@ -103,7 +99,7 @@ KNewAccountDlg::KNewAccountDlg(const MyMoneyAccount& account, bool isEditing, bo
 
   m_qlistviewParentAccounts->setRootIsDecorated(true);
   m_qlistviewParentAccounts->setAllColumnsShowFocus(true);
-  m_qlistviewParentAccounts->addColumn(columnName);
+  m_qlistviewParentAccounts->setSectionHeader(columnName);
   m_qlistviewParentAccounts->setMultiSelection(false);
   m_qlistviewParentAccounts->header()->setResizeEnabled(true);
   m_qlistviewParentAccounts->setColumnWidthMode(0, QListView::Maximum);
@@ -151,7 +147,6 @@ KNewAccountDlg::KNewAccountDlg(const MyMoneyAccount& account, bool isEditing, bo
     accountNoEdit->setEnabled(false);
 
     m_institutionBox->hide();
-    m_onlineBankingBox->hide();
     m_qcheckboxNoVat->hide();
 
     typeCombo->insertItem(KMyMoneyUtils::accountTypeToString(MyMoneyAccount::Income));
@@ -183,9 +178,16 @@ KNewAccountDlg::KNewAccountDlg(const MyMoneyAccount& account, bool isEditing, bo
   else
   {
     // get rid of the tabs that are not used for accounts
-    QWidget* tab = m_tab->page(m_tab->indexOf(m_taxTab));
-    if(tab)
-      m_tab->removePage(tab);
+    QWidget* taxtab = m_tab->page(m_tab->indexOf(m_taxTab));
+    if (taxtab) {
+      if(m_account.isAssetLiability()) {
+        m_vatCategory->setText(i18n( "VAT account"));
+        m_vatAssignmentFrame->hide();
+        m_qcheckboxTax->setChecked(account.value("Tax") == "Yes");
+      } else {
+        m_tab->removePage(taxtab);
+      }
+    }
 
     switch(m_account.accountType()) {
       case MyMoneyAccount::Savings:
@@ -204,7 +206,7 @@ KNewAccountDlg::KNewAccountDlg(const MyMoneyAccount& account, bool isEditing, bo
 
       default:
         // no limit available, so we might get rid of the tab
-        tab = m_tab->page(m_tab->indexOf(m_limitsTab));
+        QWidget* tab = m_tab->page(m_tab->indexOf(m_limitsTab));
         if(tab)
           m_tab->removePage(tab);
         // don't try to hide the widgets we just wiped
@@ -271,7 +273,6 @@ KNewAccountDlg::KNewAccountDlg(const MyMoneyAccount& account, bool isEditing, bo
         break;
       case MyMoneyAccount::Stock:
         m_institutionBox->hide();
-        m_onlineBankingBox->hide();
         typeCombo->setCurrentItem(8);
         break;
 /*
@@ -326,10 +327,7 @@ KNewAccountDlg::KNewAccountDlg(const MyMoneyAccount& account, bool isEditing, bo
       }
     }
 
-    m_qcheckboxTax->hide();
-
-    displayOnlineBankingStatus();
-
+//    m_qcheckboxTax->hide(); TODO should only be visible for VAT category/account
   }
 
   m_currency->setSecurity(file->currency(account.currencyId()));
@@ -365,24 +363,14 @@ KNewAccountDlg::KNewAccountDlg(const MyMoneyAccount& account, bool isEditing, bo
 
   // load button icons
   KIconLoader* il = KGlobal::iconLoader();
-  KGuiItem cancelButtenItem( i18n( "&Cancel" ),
-                      QIconSet(il->loadIcon("button_cancel", KIcon::Small, KIcon::SizeSmall)),
-                      i18n("Reject any changes"),
-                      i18n("Use this to abort the account/category dialog"));
-  cancelButton->setGuiItem(cancelButtenItem);
-
-  KGuiItem okButtenItem( i18n( "&OK" ),
-                      QIconSet(il->loadIcon("button_ok", KIcon::Small, KIcon::SizeSmall)),
-                      i18n("Accept modifications"),
-                      i18n("Use this to accept the data and possibly create the account/category"));
-  createButton->setGuiItem(okButtenItem);
+  cancelButton->setGuiItem(KStdGuiItem::cancel());
+  createButton->setGuiItem(KStdGuiItem::ok());
 
   connect(cancelButton, SIGNAL(clicked()), SLOT(reject()));
   connect(createButton, SIGNAL(clicked()), this, SLOT(okClicked()));
   connect(m_qlistviewParentAccounts, SIGNAL(selectionChanged(QListViewItem*)),
     this, SLOT(slotSelectionChanged(QListViewItem*)));
   connect(m_qbuttonNew, SIGNAL(clicked()), this, SLOT(slotNewClicked()));
-  connect(m_buttonOnlineSetup, SIGNAL(clicked()), this, SLOT(slotOnlineSetupClicked()));
   connect(typeCombo, SIGNAL(activated(const QString&)),
     this, SLOT(slotAccountTypeChanged(const QString&)));
 
@@ -409,8 +397,8 @@ KNewAccountDlg::KNewAccountDlg(const MyMoneyAccount& account, bool isEditing, bo
   // and certainly no children in case we create a new account
   if(!m_isEditing) {
     m_account.clearId();
-    m_account.setParentAccountId(QCString());
-    QCStringList::ConstIterator it;
+    m_account.setParentAccountId(QString());
+    QStringList::ConstIterator it;
     while((it = m_account.accountList().begin()) != m_account.accountList().end())
       m_account.removeAccountId(*it);
 
@@ -423,24 +411,22 @@ KNewAccountDlg::KNewAccountDlg(const MyMoneyAccount& account, bool isEditing, bo
       slotAccountTypeChanged(KMyMoneyUtils::accountTypeToString(type));
     }
   } else {
-    if(categoryEditor) {
-      if(!m_account.value("VatRate").isEmpty()) {
-        m_vatCategory->setChecked(true);
-        m_vatRate->setValue(MyMoneyMoney(m_account.value("VatRate"))*MyMoneyMoney(100,1));
-      } else {
-        if(!m_account.value("VatAccount").isEmpty()) {
-          QCString accId = m_account.value("VatAccount").latin1();
-          try {
-            // make sure account exists
-            MyMoneyFile::instance()->account(accId);
-            m_vatAssignment->setChecked(true);
-            m_vatAccount->setSelected(accId);
-            m_grossAmount->setChecked(true);
-            if(m_account.value("VatAmount") == "Net")
-              m_netAmount->setChecked(true);
-          } catch(MyMoneyException *e) {
-            delete e;
-          }
+    if(!m_account.value("VatRate").isEmpty()) {
+      m_vatCategory->setChecked(true);
+      m_vatRate->setValue(MyMoneyMoney(m_account.value("VatRate"))*MyMoneyMoney(100,1));
+    } else {
+      if(!m_account.value("VatAccount").isEmpty()) {
+        QString accId = m_account.value("VatAccount").latin1();
+        try {
+          // make sure account exists
+          MyMoneyFile::instance()->account(accId);
+          m_vatAssignment->setChecked(true);
+          m_vatAccount->setSelected(accId);
+          m_grossAmount->setChecked(true);
+          if(m_account.value("VatAmount") == "Net")
+            m_netAmount->setChecked(true);
+        } catch(MyMoneyException *e) {
+          delete e;
         }
       }
     }
@@ -464,7 +450,7 @@ void KNewAccountDlg::timerDone(void)
   if(m_accountItem) m_qlistviewParentAccounts->ensureItemVisible(m_accountItem);
   if(m_parentItem) m_qlistviewParentAccounts->ensureItemVisible(m_parentItem);
   // KNewAccountDlgDecl::resizeEvent(0);
-  m_qlistviewParentAccounts->setColumnWidth(0, m_qlistviewParentAccounts->visibleWidth());
+  m_qlistviewParentAccounts->setColumnWidth(m_qlistviewParentAccounts->nameColumn(), m_qlistviewParentAccounts->visibleWidth());
   m_qlistviewParentAccounts->repaintContents(false);
 }
 
@@ -522,7 +508,7 @@ void KNewAccountDlg::okClicked()
     }
     else
     {
-      m_account.setInstitutionId(QCString());
+      m_account.setInstitutionId(QString());
     }
   }
 
@@ -611,32 +597,29 @@ void KNewAccountDlg::okClicked()
     }
   }
 
-  if (m_categoryEditor)
-  {
-    if ( m_qcheckboxTax->isChecked())
-      m_account.setValue("Tax", "Yes");
-    else
-      m_account.deletePair("Tax");
+  if ( m_qcheckboxTax->isChecked())
+    m_account.setValue("Tax", "Yes");
+  else
+    m_account.deletePair("Tax");
 
-    m_account.deletePair("VatAccount");
-    m_account.deletePair("VatAmount");
-    m_account.deletePair("VatRate");
+  m_account.deletePair("VatAccount");
+  m_account.deletePair("VatAmount");
+  m_account.deletePair("VatRate");
 
-    if(m_vatCategory->isChecked()) {
-      m_account.setValue("VatRate", (m_vatRate->value().abs() / MyMoneyMoney(100,1)).toString());
-    } else {
-      if(m_vatAssignment->isChecked()) {
-        m_account.setValue("VatAccount", m_vatAccount->selectedItems().first());
-        if(m_netAmount->isChecked())
-          m_account.setValue("VatAmount", "Net");
-      }
+  if(m_vatCategory->isChecked()) {
+    m_account.setValue("VatRate", (m_vatRate->value().abs() / MyMoneyMoney(100,1)).toString());
+  } else {
+    if(m_vatAssignment->isChecked()) {
+      m_account.setValue("VatAccount", m_vatAccount->selectedItems().first());
+      if(m_netAmount->isChecked())
+        m_account.setValue("VatAmount", "Net");
     }
   }
 
   accept();
 }
 
-void KNewAccountDlg::loadKVP(const QCString& key, kMyMoneyEdit* widget)
+void KNewAccountDlg::loadKVP(const QString& key, kMyMoneyEdit* widget)
 {
   if(!widget)
     return;
@@ -648,7 +631,7 @@ void KNewAccountDlg::loadKVP(const QCString& key, kMyMoneyEdit* widget)
   }
 }
 
-void KNewAccountDlg::loadKVP(const QCString& key, KLineEdit* widget)
+void KNewAccountDlg::loadKVP(const QString& key, KLineEdit* widget)
 {
   if(!widget)
     return;
@@ -656,7 +639,7 @@ void KNewAccountDlg::loadKVP(const QCString& key, KLineEdit* widget)
   widget->setText(m_account.value(key));
 }
 
-void KNewAccountDlg::storeKVP(const QCString& key, const QString& text, const QString& value)
+void KNewAccountDlg::storeKVP(const QString& key, const QString& text, const QString& value)
 {
   if(text.isEmpty())
     m_account.deletePair(key);
@@ -664,12 +647,12 @@ void KNewAccountDlg::storeKVP(const QCString& key, const QString& text, const QS
     m_account.setValue(key, value);
 }
 
-void KNewAccountDlg::storeKVP(const QCString& key, kMyMoneyEdit* widget)
+void KNewAccountDlg::storeKVP(const QString& key, kMyMoneyEdit* widget)
 {
   storeKVP(key, widget->lineedit()->text(), widget->text());
 }
 
-void KNewAccountDlg::storeKVP(const QCString& key, KLineEdit* widget)
+void KNewAccountDlg::storeKVP(const QString& key, KLineEdit* widget)
 {
   storeKVP(key, widget->text(), widget->text());
 }
@@ -727,7 +710,7 @@ const MyMoneyAccount& KNewAccountDlg::parentAccount(void)
   return m_parentAccount;
 }
 
-void KNewAccountDlg::initParentWidget(QCString parentId, const QCString& accountId)
+void KNewAccountDlg::initParentWidget(QString parentId, const QString& accountId)
 {
   MyMoneyFile *file = MyMoneyFile::instance();
 
@@ -772,7 +755,7 @@ void KNewAccountDlg::initParentWidget(QCString parentId, const QCString& account
     {
       if(groupType == MyMoneyAccount::Asset || type == MyMoneyAccount::Loan) {
         // Asset
-        KMyMoneyAccountTreeItem *assetTopLevelAccount = new KMyMoneyAccountTreeItem(m_qlistviewParentAccounts, assetAccount);
+        KMyMoneyAccountTreeBaseItem *assetTopLevelAccount = new KMyMoneyAccountTreeItem(m_qlistviewParentAccounts, assetAccount);
 
         if(m_parentAccount.id().isEmpty()) {
           m_parentAccount = assetAccount;
@@ -784,7 +767,7 @@ void KNewAccountDlg::initParentWidget(QCString parentId, const QCString& account
 
         assetTopLevelAccount->setOpen(true);
 
-        for ( QCStringList::ConstIterator it = assetAccount.accountList().begin();
+        for ( QStringList::ConstIterator it = assetAccount.accountList().begin();
               it != assetAccount.accountList().end();
               ++it )
         {
@@ -792,7 +775,7 @@ void KNewAccountDlg::initParentWidget(QCString parentId, const QCString& account
           if(acc.isClosed())
             continue;
 
-          KMyMoneyAccountTreeItem *accountItem = new KMyMoneyAccountTreeItem(assetTopLevelAccount, acc);
+          KMyMoneyAccountTreeBaseItem *accountItem = new KMyMoneyAccountTreeItem(assetTopLevelAccount, acc);
 
           if(parentId == acc.id()) {
             m_parentItem = accountItem;
@@ -802,7 +785,7 @@ void KNewAccountDlg::initParentWidget(QCString parentId, const QCString& account
             m_accountItem = accountItem;
           }
 
-          QCStringList subAccounts = acc.accountList();
+          QStringList subAccounts = acc.accountList();
           if (subAccounts.count() >= 1)
           {
             showSubAccounts(subAccounts, accountItem, parentId, acc.id());
@@ -812,7 +795,7 @@ void KNewAccountDlg::initParentWidget(QCString parentId, const QCString& account
 
       if(groupType == MyMoneyAccount::Liability) {
         // Liability
-        KMyMoneyAccountTreeItem *liabilityTopLevelAccount = new KMyMoneyAccountTreeItem(m_qlistviewParentAccounts, liabilityAccount);
+        KMyMoneyAccountTreeBaseItem *liabilityTopLevelAccount = new KMyMoneyAccountTreeItem(m_qlistviewParentAccounts, liabilityAccount);
 
         if(m_parentAccount.id().isEmpty()) {
           m_parentAccount = liabilityAccount;
@@ -824,7 +807,7 @@ void KNewAccountDlg::initParentWidget(QCString parentId, const QCString& account
 
         liabilityTopLevelAccount->setOpen(true);
 
-        for ( QCStringList::ConstIterator it = liabilityAccount.accountList().begin();
+        for ( QStringList::ConstIterator it = liabilityAccount.accountList().begin();
               it != liabilityAccount.accountList().end();
               ++it )
         {
@@ -832,7 +815,7 @@ void KNewAccountDlg::initParentWidget(QCString parentId, const QCString& account
           if(acc.isClosed())
             continue;
 
-          KMyMoneyAccountTreeItem *accountItem = new KMyMoneyAccountTreeItem(liabilityTopLevelAccount, acc);
+          KMyMoneyAccountTreeBaseItem *accountItem = new KMyMoneyAccountTreeItem(liabilityTopLevelAccount, acc);
 
           if(parentId == acc.id()) {
             m_parentItem = accountItem;
@@ -842,7 +825,7 @@ void KNewAccountDlg::initParentWidget(QCString parentId, const QCString& account
             m_accountItem = accountItem;
           }
 
-          QCStringList subAccounts = acc.accountList();
+          QStringList subAccounts = acc.accountList();
           if (subAccounts.count() >= 1)
           {
             showSubAccounts(subAccounts, accountItem, parentId, acc.id());
@@ -854,7 +837,7 @@ void KNewAccountDlg::initParentWidget(QCString parentId, const QCString& account
     {
       if(groupType == MyMoneyAccount::Income) {
         // Income
-        KMyMoneyAccountTreeItem *incomeTopLevelAccount = new KMyMoneyAccountTreeItem(m_qlistviewParentAccounts,
+        KMyMoneyAccountTreeBaseItem *incomeTopLevelAccount = new KMyMoneyAccountTreeItem(m_qlistviewParentAccounts,
                           incomeAccount);
 
         if(m_parentAccount.id().isEmpty()) {
@@ -867,14 +850,14 @@ void KNewAccountDlg::initParentWidget(QCString parentId, const QCString& account
 
         incomeTopLevelAccount->setOpen(true);
 
-        for ( QCStringList::ConstIterator it = incomeAccount.accountList().begin();
+        for ( QStringList::ConstIterator it = incomeAccount.accountList().begin();
               it != incomeAccount.accountList().end();
               ++it )
         {
-          KMyMoneyAccountTreeItem *accountItem = new KMyMoneyAccountTreeItem(incomeTopLevelAccount,
+          KMyMoneyAccountTreeBaseItem *accountItem = new KMyMoneyAccountTreeItem(incomeTopLevelAccount,
               file->account(*it));
 
-          QCString id = file->account(*it).id();
+          QString id = file->account(*it).id();
           if(parentId == id) {
             m_parentItem = accountItem;
           } else if(accountId == id) {
@@ -883,7 +866,7 @@ void KNewAccountDlg::initParentWidget(QCString parentId, const QCString& account
             m_accountItem = accountItem;
           }
 
-          QCStringList subAccounts = file->account(*it).accountList();
+          QStringList subAccounts = file->account(*it).accountList();
           if (subAccounts.count() >= 1)
           {
             showSubAccounts(subAccounts, accountItem, parentId, accountId);
@@ -893,7 +876,7 @@ void KNewAccountDlg::initParentWidget(QCString parentId, const QCString& account
 
       if(groupType == MyMoneyAccount::Expense) {
         // Expense
-        KMyMoneyAccountTreeItem *expenseTopLevelAccount = new KMyMoneyAccountTreeItem(m_qlistviewParentAccounts,
+        KMyMoneyAccountTreeBaseItem *expenseTopLevelAccount = new KMyMoneyAccountTreeItem(m_qlistviewParentAccounts,
                           expenseAccount);
 
         if(m_parentAccount.id().isEmpty()) {
@@ -906,14 +889,14 @@ void KNewAccountDlg::initParentWidget(QCString parentId, const QCString& account
 
         expenseTopLevelAccount->setOpen(true);
 
-        for ( QCStringList::ConstIterator it = expenseAccount.accountList().begin();
+        for ( QStringList::ConstIterator it = expenseAccount.accountList().begin();
               it != expenseAccount.accountList().end();
               ++it )
         {
-          KMyMoneyAccountTreeItem *accountItem = new KMyMoneyAccountTreeItem(expenseTopLevelAccount,
+          KMyMoneyAccountTreeBaseItem *accountItem = new KMyMoneyAccountTreeItem(expenseTopLevelAccount,
               file->account(*it));
 
-          QCString id = file->account(*it).id();
+          QString id = file->account(*it).id();
           if(parentId == id) {
             m_parentItem = accountItem;
           } else if(accountId == id) {
@@ -922,7 +905,7 @@ void KNewAccountDlg::initParentWidget(QCString parentId, const QCString& account
             m_accountItem = accountItem;
           }
 
-          QCStringList subAccounts = file->account(*it).accountList();
+          QStringList subAccounts = file->account(*it).accountList();
           if (subAccounts.count() >= 1)
           {
             showSubAccounts(subAccounts, accountItem, parentId, accountId);
@@ -949,17 +932,17 @@ void KNewAccountDlg::initParentWidget(QCString parentId, const QCString& account
   m_qlistviewParentAccounts->setEnabled(true);
 }
 
-void KNewAccountDlg::showSubAccounts(QCStringList accounts, KMyMoneyAccountTreeItem *parentItem,
-                                     const QCString& parentId, const QCString& accountId)
+void KNewAccountDlg::showSubAccounts(QStringList accounts, KMyMoneyAccountTreeBaseItem *parentItem,
+                                     const QString& parentId, const QString& accountId)
 {
   MyMoneyFile *file = MyMoneyFile::instance();
 
-  for ( QCStringList::ConstIterator it = accounts.begin(); it != accounts.end(); ++it )
+  for ( QStringList::ConstIterator it = accounts.begin(); it != accounts.end(); ++it )
   {
-    KMyMoneyAccountTreeItem *accountItem  = new KMyMoneyAccountTreeItem(parentItem,
+    KMyMoneyAccountTreeBaseItem *accountItem  = new KMyMoneyAccountTreeItem(parentItem,
           file->account(*it));
 
-    QCString id = file->account(*it).id();
+    QString id = file->account(*it).id();
     if(parentId == id) {
       m_parentItem = accountItem;
     } else if(accountId == id) {
@@ -968,7 +951,7 @@ void KNewAccountDlg::showSubAccounts(QCStringList accounts, KMyMoneyAccountTreeI
       m_accountItem = accountItem;
     }
 
-    QCStringList subAccounts = file->account(*it).accountList();
+    QStringList subAccounts = file->account(*it).accountList();
     if (subAccounts.count() >= 1)
     {
       showSubAccounts(subAccounts, accountItem, parentId, accountId);
@@ -986,7 +969,7 @@ void KNewAccountDlg::resizeEvent(QResizeEvent* e)
 
 void KNewAccountDlg::slotSelectionChanged(QListViewItem *item)
 {
-  KMyMoneyAccountTreeItem *accountItem = dynamic_cast<KMyMoneyAccountTreeItem*>(item);
+  KMyMoneyAccountTreeBaseItem *accountItem = dynamic_cast<KMyMoneyAccountTreeBaseItem*>(item);
   try
   {
     MyMoneyFile *file = MyMoneyFile::instance();
@@ -1010,19 +993,31 @@ void KNewAccountDlg::loadVatAccounts(void)
   QValueList<MyMoneyAccount> list;
   MyMoneyFile::instance()->accountList(list);
   QValueList<MyMoneyAccount>::Iterator it;
-  QCStringList loadListExpense;
-  QCStringList loadListIncome;
+  QStringList loadListExpense;
+  QStringList loadListIncome;
+  QStringList loadListAsset;
+  QStringList loadListLiability;
   for(it = list.begin(); it != list.end(); ++it) {
     if(!(*it).value("VatRate").isEmpty()) {
       if((*it).accountType() == MyMoneyAccount::Expense)
         loadListExpense += (*it).id();
-      else
+      else if((*it).accountType() == MyMoneyAccount::Income)
         loadListIncome += (*it).id();
+      else if((*it).accountType() == MyMoneyAccount::Asset)
+        loadListAsset += (*it).id();
+      else if((*it).accountType() == MyMoneyAccount::Liability)
+        loadListLiability += (*it).id();
     }
   }
   AccountSet vatSet;
-  vatSet.load(m_vatAccount, i18n("Income"), loadListIncome, true);
-  vatSet.load(m_vatAccount, i18n("Expense"), loadListExpense, false);
+  if(!loadListAsset.isEmpty())
+    vatSet.load(m_vatAccount, i18n("Asset"), loadListAsset, true);
+  if(!loadListLiability.isEmpty())
+    vatSet.load(m_vatAccount, i18n("Liability"), loadListLiability, false);
+  if(!loadListIncome.isEmpty())
+    vatSet.load(m_vatAccount, i18n("Income"), loadListIncome, false);
+  if(!loadListExpense.isEmpty())
+    vatSet.load(m_vatAccount, i18n("Expense"), loadListExpense, false);
 }
 
 void KNewAccountDlg::slotLoadInstitutions(const QString& name)
@@ -1089,32 +1084,6 @@ void KNewAccountDlg::slotNewClicked()
   }
 }
 
-void KNewAccountDlg::slotOnlineSetupClicked(void)
-{
-#ifdef USE_OFX_DIRECTCONNECT
-  // TODO (Ace) This is one place to add in logic for other online banking
-  // protocols.  We could have a dialog that asks the user which
-  // protocol to set up for this account, and then call the correct
-  // wizard (using a plugin)
-  //
-  // Or, the wizard itself could ask the user.
-
-  KOnlineBankingSetupWizard wiz(this,"onlinebankingsetup");
-  if(wiz.isInit()) {
-    if(wiz.exec() == QDialog::Accepted) {
-      MyMoneyKeyValueContainer settings;
-      if ( wiz.chosenSettings( settings ) )
-      {
-        m_account.setOnlineBankingSettings( settings );
-        displayOnlineBankingStatus();
-      }
-    }
-  }
-#else
-  KMessageBox::sorry(this,i18n("This version of KMyMoney has not been compiled with support for online banking"));
-#endif
-}
-
 void KNewAccountDlg::slotAccountTypeChanged(const QString& typeStr)
 {
   MyMoneyAccount::accountTypeE type;
@@ -1125,7 +1094,7 @@ void KNewAccountDlg::slotAccountTypeChanged(const QString& typeStr)
   try {
     oldType = m_account.accountType();
     if(oldType != type) {
-      QCString parentId;
+      QString parentId;
       switch(MyMoneyAccount::accountGroup(type)) {
         case MyMoneyAccount::Asset:
           parentId = file->asset().id();
@@ -1143,7 +1112,8 @@ void KNewAccountDlg::slotAccountTypeChanged(const QString& typeStr)
           qWarning("Unknown account group in KNewAccountDlg::slotAccountTypeChanged()");
           break;
       }
-      initParentWidget(parentId, QCString());
+      initParentWidget(parentId, QString());
+      m_account.setAccountType(type);
     }
   } catch(MyMoneyException *e) {
     delete e;
@@ -1175,7 +1145,9 @@ void KNewAccountDlg::slotVatChanged(bool state)
     m_vatAssignmentFrame->hide();
   } else {
     m_vatCategoryFrame->hide();
-    m_vatAssignmentFrame->show();
+    if(!m_account.isAssetLiability()) {
+        m_vatAssignmentFrame->show();
+    }
   }
 }
 
@@ -1185,35 +1157,6 @@ void KNewAccountDlg::slotVatAssignmentChanged(bool state)
   m_amountGroup->setEnabled(state);
 }
 
-void KNewAccountDlg::displayOnlineBankingStatus(void)
-{
-// this should be a run-time conditional, checking whether there are any online
-// banking plugins loaded
-#ifdef USE_OFX_DIRECTCONNECT
-    // Set up online banking settings if applicable
-    MyMoneyKeyValueContainer settings = m_account.onlineBankingSettings();
-    QString protocol = settings.value("protocol");
-    if ( ! protocol.isEmpty() )
-    {
-      m_textOnlineStatus->setText(i18n("STATUS: Enabled & configured (%1)").arg(protocol));
-      m_ledOnlineStatus->on();
-
-      QString account = i18n("ACCOUNT: %1").arg(settings.value("accountid"));
-      QString bank = i18n("BANK/BROKER: %1").arg(settings.value("bankname"));
-      QString bankid = settings.value("bankid") + " " + settings.value("branchid");
-      if ( bankid.length() > 1 )
-        bank += " (" + bankid + ")";
-      m_textBank->setText(bank);
-      m_textOnlineAccount->setText(account);
-    }
-    else
-      m_textOnlineStatus->setText(i18n("STATUS: Account not configured"));
-
-#else
-    m_textOnlineStatus->setText(i18n("STATUS: Disabled.  No online banking services are available"));
-#endif
-}
-
 void KNewAccountDlg::adjustEditWidgets(kMyMoneyEdit* dst, kMyMoneyEdit* src, char mode, int corr)
 {
   MyMoneyMoney factor(corr, 1);
@@ -1253,5 +1196,14 @@ void KNewAccountDlg::slotAdjustMaxCreditEarlyEdit(const QString&)
   adjustEditWidgets(m_maxCreditEarlyEdit, m_maxCreditAbsoluteEdit, '>', 1);
 }
 
+void KNewAccountDlg::addTab(QWidget* w, const QString& name)
+{
+  if(w) {
+    w->reparent(m_tab, QPoint(0,0));
+    m_tab->addTab(w, name);
+  }
+}
+
+
 #include "knewaccountdlg.moc"
 // vim:cin:si:ai:et:ts=2:sw=2:
