@@ -37,6 +37,7 @@
 #include <qpushbutton.h>
 #include <qradiobutton.h>
 #include <qlayout.h>
+#include <qspinbox.h>
 #include <qtooltip.h>
 #include <qwhatsthis.h>
 #include <qtabwidget.h>
@@ -115,6 +116,7 @@ KReportConfigurationFilterDlg::KReportConfigurationFilterDlg(
       m_tab2 = new kMyMoneyReportConfigTab2Decl( m_criteriaTab, "kMyMoneyReportConfigTab2" );
       m_criteriaTab->insertTab( m_tab2, i18n( "Rows/Columns"), 1 );
       connect(m_tab2->m_comboRows, SIGNAL(highlighted(int)), this, SLOT(slotRowTypeChanged(int)));
+      connect(m_tab2->m_comboColumns, SIGNAL(activated(int)), this, SLOT(slotColumnTypeChanged(int)));
       //control the state of the includeTransfer check
       connect(m_categoriesView, SIGNAL(stateChanged()), this, SLOT(slotUpdateCheckTransfers()));
 
@@ -199,7 +201,12 @@ void KReportConfigurationFilterDlg::slotSearch(void)
     if(m_tab2->m_comboBudget->isEnabled()) {
       m_currentState.setBudget(m_budgets[m_tab2->m_comboBudget->currentItem()].id(), m_initialState.rowType() == MyMoneyReport::eBudgetActual);
     } else {
-      m_currentState.setBudget(QCString(), false);
+      m_currentState.setBudget(QString(), false);
+    }
+    
+    //set moving average days
+    if(m_tab2->m_movingAverageDays->isEnabled()) {
+      m_currentState.setMovingAverageDays( m_tab2->m_movingAverageDays->value() );
     }
   }
   else if ( m_tab3 )
@@ -252,6 +259,7 @@ void KReportConfigurationFilterDlg::slotSearch(void)
     m_currentState.setChartGridLines( m_tabChart->m_checkGridLines->isChecked() );
     m_currentState.setChartDataLabels( m_tabChart->m_checkValues->isChecked() );
     m_currentState.setChartByDefault( m_tabChart->m_checkShowChart->isChecked() );
+    m_currentState.setChartLineWidth( m_tabChart->m_lineWidth->value() );
   }
 
   // setup the date lock
@@ -266,6 +274,13 @@ void KReportConfigurationFilterDlg::slotRowTypeChanged(int row)
   m_tab2->m_checkTotalColumn->setEnabled(row == 0);
 }
 
+void KReportConfigurationFilterDlg::slotColumnTypeChanged(int row)
+{
+  if(m_tab2->m_comboBudget->isEnabled() && row < 2) {
+    m_tab2->m_comboColumns->setCurrentItem(2);
+  }
+}
+
 void KReportConfigurationFilterDlg::slotReset(void)
 {
   //
@@ -369,6 +384,12 @@ void KReportConfigurationFilterDlg::slotReset(void)
       }
     }
 
+    //set moving average days spinbox
+    m_tab2->m_movingAverageDays->setEnabled( m_initialState.isIncludingMovingAverage() );
+    if(m_initialState.isIncludingMovingAverage() ) {
+      m_tab2->m_movingAverageDays->setValue( m_initialState.movingAverageDays() );
+    }
+
     m_tab2->m_checkScheduled->setChecked( m_initialState.isIncludingSchedules() );
     m_tab2->m_checkTransfers->setChecked( m_initialState.isIncludingTransfers() );
     m_tab2->m_checkUnused->setChecked( m_initialState.isIncludingUnusedAccounts() );
@@ -449,6 +470,7 @@ void KReportConfigurationFilterDlg::slotReset(void)
     m_tabChart->m_checkGridLines->setChecked(m_initialState.isChartGridLines());
     m_tabChart->m_checkValues->setChecked(m_initialState.isChartDataLabels());
     m_tabChart->m_checkShowChart->setChecked(m_initialState.isChartByDefault());
+    m_tabChart->m_lineWidth->setValue(m_initialState.chartLineWidth());
   }
 
   //
@@ -461,6 +483,7 @@ void KReportConfigurationFilterDlg::slotReset(void)
     m_textEdit->setText(textfilter.pattern());
     m_caseSensitive->setChecked(textfilter.caseSensitive());
     m_regExp->setChecked(!textfilter.wildcard());
+    m_textNegate->setCurrentItem(m_initialState.isInvertingText());
   }
 
   //
@@ -563,7 +586,7 @@ void KReportConfigurationFilterDlg::slotReset(void)
   // Payees Filter
   //
 
-  QCStringList payees;
+  QStringList payees;
   if ( m_initialState.payees(payees) )
   {
     if ( payees.empty() )
@@ -585,7 +608,7 @@ void KReportConfigurationFilterDlg::slotReset(void)
   // Accounts Filter
   //
 
-  QCStringList accounts;
+  QStringList accounts;
   if ( m_initialState.accounts(accounts) )
   {
     m_accountsView->selectAllItems(false);
