@@ -38,12 +38,11 @@
 #include <kglobal.h>
 #include <kconfig.h>
 #include <klocale.h>
-//#include <kiconloader.h>
-//#include <kguiitem.h>
 #include <kmessagebox.h>
 #include <kpushbutton.h>
 #include <kactivelabel.h>
 #include <kstdguiitem.h>
+#include <kapplication.h>
 
 // ----------------------------------------------------------------------------
 // Project Includes
@@ -62,10 +61,9 @@ KSplitTransactionDlg::KSplitTransactionDlg(const MyMoneyTransaction& t,
                                            const bool amountValid,
                                            const bool deposit,
                                            const MyMoneyMoney& calculatedValue,
-                                           const QMap<QCString, MyMoneyMoney>& priceInfo,
-                                           QWidget* parent, const char* name)
-  : KSplitTransactionDlgDecl(parent, name, true),
-  m_transaction(t),
+                                           const QMap<QString, MyMoneyMoney>& priceInfo,
+                                           QWidget* parent, const char* name) :
+  KSplitTransactionDlgDecl(parent, name, true),
   m_account(acc),
   m_split(s),
   m_precision(2),
@@ -75,17 +73,6 @@ KSplitTransactionDlg::KSplitTransactionDlg(const MyMoneyTransaction& t,
 {
   // add icons to buttons
   KIconLoader *il = KGlobal::iconLoader();
-  KGuiItem finishButtenItem( i18n( "&Finish" ),
-                    QIconSet(il->loadIcon("button_ok", KIcon::Small, KIcon::SizeSmall)),
-                    i18n("Accept splits and return to transaction form"),
-                    i18n("Use this to accept all changes to the splits and return to the transaction"));
-  finishBtn->setGuiItem(finishButtenItem);
-
-  KGuiItem cancelButtenItem( i18n( "&Cancel" ),
-                    QIconSet(il->loadIcon("button_cancel", KIcon::Small, KIcon::SizeSmall)),
-                    i18n("Reject all changes to the splits and return to transaction form"),
-                    i18n("Use this to reject all changes to the splits and return to the transaction"));
-  cancelBtn->setGuiItem(cancelButtenItem);
 
   KGuiItem clearButtenItem( i18n( "Clear &All" ),
                     QIconSet(il->loadIcon("edittrash", KIcon::Small, KIcon::SizeSmall)),
@@ -94,6 +81,11 @@ KSplitTransactionDlg::KSplitTransactionDlg(const MyMoneyTransaction& t,
   clearAllBtn->setGuiItem(clearButtenItem);
 
 
+  KGuiItem mergeButtenItem( i18n( "&Merge" ),
+                             QIconSet(il->loadIcon("math_sum", KIcon::Small, KIcon::SizeSmall)),
+                                      "", "");
+  mergeBtn->setGuiItem(mergeButtenItem);
+
   // make finish the default
   finishBtn->setDefault(true);
 
@@ -105,7 +97,7 @@ KSplitTransactionDlg::KSplitTransactionDlg(const MyMoneyTransaction& t,
   // connect signals with slots
   connect(transactionsTable, SIGNAL(transactionChanged(const MyMoneyTransaction&)),
           this, SLOT(slotSetTransaction(const MyMoneyTransaction&)));
-  connect(transactionsTable, SIGNAL(createCategory(const QString&, QCString&)), this, SLOT(slotCreateCategory(const QString&, QCString&)));
+  connect(transactionsTable, SIGNAL(createCategory(const QString&, QString&)), this, SLOT(slotCreateCategory(const QString&, QString&)));
   connect(transactionsTable, SIGNAL(objectCreation(bool)), this, SIGNAL(objectCreation(bool)));
 
   connect(transactionsTable, SIGNAL(returnPressed()), this, SLOT(accept()));
@@ -114,17 +106,28 @@ KSplitTransactionDlg::KSplitTransactionDlg(const MyMoneyTransaction& t,
   connect(cancelBtn, SIGNAL(clicked()), this, SLOT(reject()));
   connect(finishBtn, SIGNAL(clicked()), this, SLOT(accept()));
   connect(clearAllBtn, SIGNAL(clicked()), this, SLOT(slotClearAllSplits()));
+  connect(mergeBtn, SIGNAL(clicked()), this, SLOT(slotMergeSplits()));
+  connect(clearZeroBtn, SIGNAL(clicked()), this, SLOT(slotClearUnusedSplits()));
 
   // setup the precision
   try {
-    m_precision = MyMoneyMoney::denomToPrec(m_account.fraction());
+    MyMoneySecurity currency = MyMoneyFile::instance()->currency(t.commodity());
+    m_precision = MyMoneyMoney::denomToPrec(m_account.fraction(currency));
   } catch(MyMoneyException *e) {
     delete e;
   }
 
+  slotSetTransaction(t);
+
   // pass on those vars
   transactionsTable->setup(priceInfo);
 
+  QSize size(width(), height());
+  kapp->config()->setGroup("SplitTransactionEditor");
+  size = kapp->config()->readSizeEntry("Geometry", &size);
+  size.setHeight(size.height()-1);
+  QDialog::resize( size.expandedTo(minimumSizeHint()) );
+
   // Trick: it seems, that the initial sizing of the dialog does
   // not work correctly. At least, the columns do not get displayed
   // correct. Reason: the return value of transactionsTable->visibleWidth()
@@ -136,6 +139,8 @@ KSplitTransactionDlg::KSplitTransactionDlg(const MyMoneyTransaction& t,
 
 KSplitTransactionDlg::~KSplitTransactionDlg()
 {
+  kapp->config()->setGroup("SplitTransactionEditor");
+  kapp->config()->writeEntry("Geometry", size());
 }
 
 int KSplitTransactionDlg::exec(void)
@@ -263,8 +268,9 @@ void KSplitTransactionDlg::reject()
   KSplitTransactionDlgDecl::reject();
 }
 
-void KSplitTransactionDlg::slotClearAllSplits()
+void KSplitTransactionDlg::slotClearAllSplits(void)
 {
+  transactionsTable->slotEndEdit();
   int answer;
   answer = KMessageBox::warningContinueCancel (this,
      i18n("You are about to delete all splits of this transaction. "
@@ -288,25 +294,107 @@ void KSplitTransactionDlg::slotClearAllSplits()
   }
 }
 
+void KSplitTransactionDlg::slotClearUnusedSplits(void)
+{
+  transactionsTable->slotEndEdit();
+
+  QValueList<MyMoneySplit> list = transactionsTable->getSplits(m_transaction);
+  QValueList<MyMoneySplit>::ConstIterator it;
+
+  try {
+    // remove all splits that don't have a value assigned
+    for(it = list.begin(); it != list.end(); ++it) {
+      if((*it).shares().isZero()) {
+        m_transaction.removeSplit(*it);
+      }
+    }
+
+    transactionsTable->setTransaction(m_transaction, m_split, m_account);
+    slotSetTransaction(m_transaction);
+  } catch(MyMoneyException* e) {
+    delete e;
+  }
+}
+
+void KSplitTransactionDlg::slotMergeSplits(void)
+{
+  transactionsTable->slotEndEdit();
+
+  QValueList<MyMoneySplit> list = transactionsTable->getSplits(m_transaction);
+  QValueList<MyMoneySplit>::ConstIterator it;
+
+  try {
+    // collect all splits, merge them if needed and remove from transaction
+    QValueList<MyMoneySplit> splits;
+    for(it = list.begin(); it != list.end(); ++it) {
+      QValueList<MyMoneySplit>::iterator it_s;
+      for(it_s = splits.begin(); it_s != splits.end(); ++it_s) {
+        if((*it_s).accountId() == (*it).accountId()
+        && (*it_s).memo().isEmpty() && (*it).memo().isEmpty())
+          break;
+      }
+      if(it_s != splits.end()) {
+        (*it_s).setShares((*it).shares() + (*it_s).shares());
+        (*it_s).setValue((*it).value() + (*it_s).value());
+      } else {
+        splits << *it;
+      }
+      m_transaction.removeSplit(*it);
+    }
+
+    // now add them back to the transaction
+    QValueList<MyMoneySplit>::iterator it_s;
+    for(it_s = splits.begin(); it_s != splits.end(); ++it_s) {
+      (*it_s).clearId();
+      m_transaction.addSplit(*it_s);
+    }
+
+    transactionsTable->setTransaction(m_transaction, m_split, m_account);
+    slotSetTransaction(m_transaction);
+  } catch(MyMoneyException* e) {
+    delete e;
+  }
+}
+
 void KSplitTransactionDlg::slotSetTransaction(const MyMoneyTransaction& t)
 {
+  transactionsTable->slotCancelEdit();
+
   m_transaction = t;
+  QValueList<MyMoneySplit> list = transactionsTable->getSplits(m_transaction);
+  QValueList<MyMoneySplit>::ConstIterator it;
+
+  // check if we can merge splits or not, have zero splits or not
+  QMap<QString, int> splits;
+  bool haveZeroSplit = false;
+  for(it = list.begin(); it != list.end(); ++it) {
+    splits[(*it).accountId()]++;
+    if(((*it).id() != m_split.id()) && ((*it).shares().isZero()))
+      haveZeroSplit = true;
+  }
+  QMap<QString, int>::const_iterator it_s;
+  for(it_s = splits.begin(); it_s != splits.end(); ++it_s) {
+    if((*it_s) > 1)
+      break;
+  }
+  mergeBtn->setDisabled(it_s == splits.end());
+  clearZeroBtn->setEnabled(haveZeroSplit);
+
   updateSums();
 }
 
 void KSplitTransactionDlg::updateSums(void)
 {
   MyMoneyMoney splits(splitsValue());
-  MyMoneySplit split = m_transaction.splits()[0];
 
   if(m_amountValid == false) {
-    split.setValue(-splits);
-    m_transaction.modifySplit(split);
+    m_split.setValue(-splits);
+    m_transaction.modifySplit(m_split);
   }
 
   splitSum->setText("<b>" + splits.formatMoney("", m_precision) + " ");
   splitUnassigned->setText("<b>" + diffAmount().formatMoney("", m_precision) + " ");
-  transactionAmount->setText("<b>" + (-split.value()).formatMoney("", m_precision) + " ");
+  transactionAmount->setText("<b>" + (-m_split.value()).formatMoney("", m_precision) + " ");
 }
 
 MyMoneyMoney KSplitTransactionDlg::splitsValue(void)
@@ -338,7 +426,7 @@ MyMoneyMoney KSplitTransactionDlg::diffAmount(void)
   return diff;
 }
 
-void KSplitTransactionDlg::slotCreateCategory(const QString& name, QCString& id)
+void KSplitTransactionDlg::slotCreateCategory(const QString& name, QString& id)
 {
   MyMoneyAccount acc, parent;
   acc.setName(name);
