@@ -59,7 +59,7 @@
 using namespace KMyMoneyRegister;
 using namespace KMyMoneyTransactionForm;
 
-TransactionEditor::TransactionEditor(TransactionEditorContainer* regForm, KMyMoneyRegister::Transaction* item, const QValueList<KMyMoneyRegister::SelectedTransaction>& list, const QDate& lastPostDate) :
+TransactionEditor::TransactionEditor(TransactionEditorContainer* regForm, KMyMoneyRegister::Transaction* item, const KMyMoneyRegister::SelectedTransactions& list, const QDate& lastPostDate) :
   m_transactions(list),
   m_regForm(regForm),
   m_item(item),
@@ -86,15 +86,30 @@ TransactionEditor::~TransactionEditor()
   emit finishEdit(m_transactions);
 }
 
-void TransactionEditor::slotUpdateAccount(const QCString& id)
+void TransactionEditor::slotUpdateAccount(const QString& id)
 {
   m_account = MyMoneyFile::instance()->account(id);
+  setupPrecision();
 }
 
 void TransactionEditor::slotUpdateAccount(void)
 {
   // reload m_account as it might have been changed
   m_account = MyMoneyFile::instance()->account(m_account.id());
+  setupPrecision();
+}
+
+void TransactionEditor::setupPrecision(void)
+{
+  const int prec = (m_account.id().isEmpty()) ? 2 : MyMoneyMoney::denomToPrec(m_account.fraction());
+  QStringList widgets = QStringList::split(",", "amount,deposit,payment");
+  QStringList::const_iterator it_w;
+  for(it_w = widgets.begin(); it_w != widgets.end(); ++it_w) {
+    QWidget * w;
+    if((w = haveWidget(*it_w)) != 0) {
+      dynamic_cast<kMyMoneyEdit*>(w)->setPrecision(prec);
+    }
+  }
 }
 
 void TransactionEditor::setup(QWidgetList& tabOrderWidgets, const MyMoneyAccount& account, KMyMoneyRegister::Action action)
@@ -316,7 +331,7 @@ bool TransactionEditor::fixTransactionCommodity(const MyMoneyAccount& account)
   int fract = m_account.fraction();
 
   // scan the list of selected transactions
-  QValueList<KMyMoneyRegister::SelectedTransaction>::iterator it_t;
+  KMyMoneyRegister::SelectedTransactions::iterator it_t;
   for(it_t = m_transactions.begin(); (rc == true) && (it_t != m_transactions.end()); ++it_t) {
     // there was a time when the schedule editor did not setup the transaction commodity
     // let's give a helping hand here for those old schedules
@@ -455,7 +470,7 @@ bool TransactionEditor::canAssignNumber(void) const
   return (number != 0) && (number->text().isEmpty());
 }
 
-void TransactionEditor::setupCategoryWidget(KMyMoneyCategory* category, const QValueList<MyMoneySplit>& splits, QCString& categoryId, const char* splitEditSlot, bool /* allowObjectCreation */)
+void TransactionEditor::setupCategoryWidget(KMyMoneyCategory* category, const QValueList<MyMoneySplit>& splits, QString& categoryId, const char* splitEditSlot, bool /* allowObjectCreation */)
 {
   disconnect(category, SIGNAL(focusIn()), this, splitEditSlot);
 #if 0
@@ -467,13 +482,13 @@ void TransactionEditor::setupCategoryWidget(KMyMoneyCategory* category, const QV
 
   switch(splits.count()) {
     case 0:
-      categoryId = QCString();
+      categoryId = QString();
       if(!category->currentText().isEmpty()) {
         category->setCurrentText();
         // make sure, we don't see the selector
         category->completion()->hide();
       }
-      category->completion()->setSelected(QCString());
+      category->completion()->setSelected(QString());
       break;
 
     case 1:
@@ -483,7 +498,7 @@ void TransactionEditor::setupCategoryWidget(KMyMoneyCategory* category, const QV
       break;
 
     default:
-      categoryId = QCString();
+      categoryId = QString();
       category->setSplitTransaction();
       connect(category, SIGNAL(focusIn()), this, splitEditSlot);
 #if 0
@@ -496,9 +511,9 @@ void TransactionEditor::setupCategoryWidget(KMyMoneyCategory* category, const QV
   }
 }
 
-bool TransactionEditor::enterTransactions(QCString& newId, bool askForSchedule)
+bool TransactionEditor::enterTransactions(QString& newId, bool askForSchedule, bool suppressBalanceWarnings)
 {
-  newId = QCString();
+  newId = QString();
   MyMoneyFile* file = MyMoneyFile::instance();
 
   // make sure to run through all stuff that is tied to 'focusout events'.
@@ -508,7 +523,7 @@ bool TransactionEditor::enterTransactions(QCString& newId, bool askForSchedule)
   // we don't need to update our widgets anymore, so we just disconnect the signal
   disconnect(file, SIGNAL(dataChanged()), this, SLOT(slotReloadEditWidgets()));
 
-  QValueList<KMyMoneyRegister::SelectedTransaction>::iterator it_t;
+  KMyMoneyRegister::SelectedTransactions::iterator it_t;
   MyMoneyTransaction t;
   bool newTransactionCreated = false;
 
@@ -546,17 +561,17 @@ bool TransactionEditor::enterTransactions(QCString& newId, bool askForSchedule)
 
     try {
       QValueList<MyMoneyTransaction>::iterator it_ts;
-      QMap<QCString, bool> minBalanceEarly;
-      QMap<QCString, bool> minBalanceAbsolute;
-      QMap<QCString, bool> maxCreditEarly;
-      QMap<QCString, bool> maxCreditAbsolute;
-      QMap<QCString, bool> accountIds;
+      QMap<QString, bool> minBalanceEarly;
+      QMap<QString, bool> minBalanceAbsolute;
+      QMap<QString, bool> maxCreditEarly;
+      QMap<QString, bool> maxCreditAbsolute;
+      QMap<QString, bool> accountIds;
 
       for(it_ts = list.begin(); it_ts != list.end(); ++it_ts) {
         // if we have a categorization, make sure we remove
         // the 'imported' flag automagically
         if((*it_ts).splitCount() > 1)
-          (*it_ts).deletePair("Imported");
+          (*it_ts).setImported(false);
 
         // create information about min and max balances
         QValueList<MyMoneySplit>::const_iterator it_s;
@@ -601,8 +616,9 @@ bool TransactionEditor::enterTransactions(QCString& newId, bool askForSchedule)
             file->addTransaction(*it_ts);
             // pass the newly assigned id on to the caller
             newId = (*it_ts).id();
-            // refresh account object for transactional changes
+            // refresh account and transaction object because they might have changed
             m_account = file->account(m_account.id());
+            t = (*it_ts);
 
             // if a new transaction has a valid number, keep it with the account
             QString number = (*it_ts).splits()[0].number();
@@ -632,52 +648,61 @@ bool TransactionEditor::enterTransactions(QCString& newId, bool askForSchedule)
 
       // update m_transactions to contain the newly created transaction so that
       // it is selected as the current one
+      // we need to do that before we commit the transaction to the engine
+      // as we need it during the update of the views that is caused by committing already.
       if(newTransactionCreated) {
         m_transactions.clear();
-        KMyMoneyRegister::SelectedTransaction s((*it_ts), (*it_ts).splits()[0]);
-        m_transactions.append(s);
+        MyMoneySplit s;
+        // a transaction w/o a single split should not exist and adding it
+        // should throw an exception in MyMoneyFile::addTransaction, but we
+        // remain on the save side of things to check for it
+        if(t.splitCount() > 0)
+          s = t.splits()[0];
+        KMyMoneyRegister::SelectedTransaction st(t, s);
+        m_transactions.append(st);
       }
 
       ft.commit();
 
       // now analyse the balances and spit out warnings to the user
-      QMap<QCString, bool>::const_iterator it_a;
+      QMap<QString, bool>::const_iterator it_a;
 
-      for(it_a = accountIds.begin(); it_a != accountIds.end(); ++it_a) {
-        QString msg;
-        MyMoneyAccount acc = file->account(it_a.key());
-        MyMoneyMoney balance = file->balance(acc.id());
-        const MyMoneySecurity& sec = file->security(acc.currencyId());
-        QCString key;
-        key = "minBalanceEarly";
-        if(!acc.value(key).isEmpty()) {
-          if(minBalanceEarly[acc.id()] == false && balance < MyMoneyMoney(acc.value(key))) {
-            msg = QString("<qt>%1</qt>").arg(i18n("The balance of account <b>%1</b> dropped below the warning balance of %2.").arg(acc.name(), MyMoneyMoney(acc.value(key)).formatMoney(acc, sec)));
+      if(!suppressBalanceWarnings) {
+        for(it_a = accountIds.begin(); it_a != accountIds.end(); ++it_a) {
+          QString msg;
+          MyMoneyAccount acc = file->account(it_a.key());
+          MyMoneyMoney balance = file->balance(acc.id());
+          const MyMoneySecurity& sec = file->security(acc.currencyId());
+          QString key;
+          key = "minBalanceEarly";
+          if(!acc.value(key).isEmpty()) {
+            if(minBalanceEarly[acc.id()] == false && balance < MyMoneyMoney(acc.value(key))) {
+              msg = QString("<qt>%1</qt>").arg(i18n("The balance of account <b>%1</b> dropped below the warning balance of %2.").arg(acc.name(), MyMoneyMoney(acc.value(key)).formatMoney(acc, sec)));
+            }
           }
-        }
-        key = "minBalanceAbsolute";
-        if(!acc.value(key).isEmpty()) {
-          if(minBalanceAbsolute[acc.id()] == false && balance < MyMoneyMoney(acc.value(key))) {
-            msg = QString("<qt>%1</qt>").arg(i18n("The balance of account <b>%1</b> dropped below the minimum balance of %2.").arg(acc.name(), MyMoneyMoney(acc.value(key)).formatMoney(acc, sec)));
+          key = "minBalanceAbsolute";
+          if(!acc.value(key).isEmpty()) {
+            if(minBalanceAbsolute[acc.id()] == false && balance < MyMoneyMoney(acc.value(key))) {
+              msg = QString("<qt>%1</qt>").arg(i18n("The balance of account <b>%1</b> dropped below the minimum balance of %2.").arg(acc.name(), MyMoneyMoney(acc.value(key)).formatMoney(acc, sec)));
+            }
           }
-        }
-        key = "maxCreditEarly";
-        if(!acc.value(key).isEmpty()) {
-          if(maxCreditEarly[acc.id()] == false && balance < MyMoneyMoney(acc.value(key))) {
-            msg = QString("<qt>%1</qt>").arg(i18n("The balance of account <b>%1</b> dropped below the maximum credit warning limit of %2.").arg(acc.name(), MyMoneyMoney(acc.value(key)).formatMoney(acc, sec)));
+          key = "maxCreditEarly";
+          if(!acc.value(key).isEmpty()) {
+            if(maxCreditEarly[acc.id()] == false && balance < MyMoneyMoney(acc.value(key))) {
+              msg = QString("<qt>%1</qt>").arg(i18n("The balance of account <b>%1</b> dropped below the maximum credit warning limit of %2.").arg(acc.name(), MyMoneyMoney(acc.value(key)).formatMoney(acc, sec)));
+            }
           }
-        }
-        key = "maxCreditAbsolute";
-        if(!acc.value(key).isEmpty()) {
-          if(maxCreditAbsolute[acc.id()] == false && balance < MyMoneyMoney(acc.value(key))) {
-            msg = QString("<qt>%1</qt>").arg(i18n("The balance of account <b>%1</b> dropped below the maximum credit limit of %2.").arg(acc.name(), MyMoneyMoney(acc.value(key)).formatMoney(acc, sec)));
+          key = "maxCreditAbsolute";
+          if(!acc.value(key).isEmpty()) {
+            if(maxCreditAbsolute[acc.id()] == false && balance < MyMoneyMoney(acc.value(key))) {
+              msg = QString("<qt>%1</qt>").arg(i18n("The balance of account <b>%1</b> dropped below the maximum credit limit of %2.").arg(acc.name(), MyMoneyMoney(acc.value(key)).formatMoney(acc, sec)));
+            }
           }
-        }
 
-        if(!msg.isEmpty()) {
-          KMessageBox::information(m_regForm, msg);
+          if(!msg.isEmpty()) {
+            emit balanceWarning(m_regForm, acc, msg);
+          }
         }
-
       }
     } catch(MyMoneyException * e) {
       qDebug("Unable to store transaction within engine: %s", e->what().latin1());
@@ -697,36 +722,64 @@ StdTransactionEditor::StdTransactionEditor()
 {
 }
 
-StdTransactionEditor::StdTransactionEditor(TransactionEditorContainer* regForm, KMyMoneyRegister::Transaction* item, const QValueList<KMyMoneyRegister::SelectedTransaction>& list, const QDate& lastPostDate) :
+StdTransactionEditor::StdTransactionEditor(TransactionEditorContainer* regForm, KMyMoneyRegister::Transaction* item, const KMyMoneyRegister::SelectedTransactions& list, const QDate& lastPostDate) :
   TransactionEditor(regForm, item, list, lastPostDate),
   m_inUpdateVat(false)
 {
 }
 
+StdTransactionEditor::~StdTransactionEditor()
+{
+  KMyMoneyTransactionForm::TransactionForm* form = dynamic_cast<KMyMoneyTransactionForm::TransactionForm*>(m_regForm);
+  if(form) {
+    form->enableTabBar(true);
+  }
+}
+
+bool StdTransactionEditor::eventFilter(QObject* o, QEvent* e)
+{
+  bool rc = TransactionEditor::eventFilter(o, e);
+
+#if 0
+  // this is sofar dead code here, as the focus out event for Comboboxes
+  // never comes along here. I don't know why (ipwizard - 2009-10-03)
+  if((e->type() == QEvent::FocusOut)
+  && (haveWidget("payee") == dynamic_cast<QWidget*>(o))) {
+    // loosing the focus on the payee widget?
+    qDebug("Loosing focus on payee");
+    KMyMoneyPayeeCombo* p = dynamic_cast<KMyMoneyPayeeCombo*>(haveWidget("payee"));
+    if(!p->selectedItem().isEmpty())
+      slotUpdatePayee(p->selectedItem());
+  }
+#endif
+  return rc;
+}
+
 void StdTransactionEditor::createEditWidgets(void)
 {
   KMyMoneyCategory* account = new KMyMoneyCategory;
   account->setHint(i18n("Account"));
   m_editWidgets["account"] = account;
   connect(account, SIGNAL(textChanged(const QString&)), this, SLOT(slotUpdateButtonState()));
-  connect(account, SIGNAL(itemSelected(const QCString&)), this, SLOT(slotUpdateAccount(const QCString&)));
+  connect(account, SIGNAL(itemSelected(const QString&)), this, SLOT(slotUpdateAccount(const QString&)));
 
   KMyMoneyPayeeCombo* payee = new KMyMoneyPayeeCombo;
   payee->setHint(i18n("Payer/Receiver"));
   m_editWidgets["payee"] = payee;
   connect(payee, SIGNAL(textChanged(const QString&)), this, SLOT(slotUpdateButtonState()));
-  connect(payee, SIGNAL(createItem(const QString&, QCString&)), this, SIGNAL(createPayee(const QString&, QCString&)));
+  connect(payee, SIGNAL(createItem(const QString&, QString&)), this, SIGNAL(createPayee(const QString&, QString&)));
   connect(payee, SIGNAL(objectCreation(bool)), this, SIGNAL(objectCreation(bool)));
-  connect(payee, SIGNAL(itemSelected(const QCString&)), this, SLOT(slotUpdatePayee(const QCString&)));
+  connect(payee, SIGNAL(itemSelected(const QString&)), this, SLOT(slotUpdatePayee(const QString&)));
 
   KMyMoneyCategory* category = new KMyMoneyCategory(0, 0, true);
   category->setHint(i18n("Category/Account"));
   m_editWidgets["category"] = category;
-  connect(category, SIGNAL(itemSelected(const QCString&)), this, SLOT(slotUpdateCategory(const QCString&)));
+  connect(category, SIGNAL(itemSelected(const QString&)), this, SLOT(slotUpdateCategory(const QString&)));
   connect(category, SIGNAL(textChanged(const QString&)), this, SLOT(slotUpdateButtonState()));
-  connect(category, SIGNAL(createItem(const QString&, QCString&)), this, SLOT(slotCreateCategory(const QString&, QCString&)));
+  connect(category, SIGNAL(createItem(const QString&, QString&)), this, SLOT(slotCreateCategory(const QString&, QString&)));
   connect(category, SIGNAL(objectCreation(bool)), this, SIGNAL(objectCreation(bool)));
   connect(category->splitButton(), SIGNAL(clicked()), this, SLOT(slotEditSplits()));
+  category->splitButton()->setDisabled(true);
 
   KTextEdit* memo = new KTextEdit;
   memo->setTabChangesFocus(true);
@@ -762,6 +815,7 @@ void StdTransactionEditor::createEditWidgets(void)
   }
 
   m_editWidgets["postdate"] = new kMyMoneyDateInput;
+  connect(m_editWidgets["postdate"], SIGNAL(dateChanged(const QDate&)), this, SLOT(slotUpdateButtonState()));
 
   kMyMoneyEdit* value = new kMyMoneyEdit;
   m_editWidgets["amount"] = value;
@@ -788,7 +842,7 @@ void StdTransactionEditor::createEditWidgets(void)
 
   KMyMoneyReconcileCombo* reconcile = new KMyMoneyReconcileCombo;
   m_editWidgets["status"] = reconcile;
-  connect(reconcile, SIGNAL(itemSelected(const QCString&)), this, SLOT(slotUpdateButtonState()));
+  connect(reconcile, SIGNAL(itemSelected(const QString&)), this, SLOT(slotUpdateButtonState()));
 
   KMyMoneyRegister::QWidgetContainer::iterator it_w;
   for(it_w = m_editWidgets.begin(); it_w != m_editWidgets.end(); ++it_w) {
@@ -808,6 +862,7 @@ void StdTransactionEditor::createEditWidgets(void)
   // create a copy of tabbar above the form (if we are created for a form)
   KMyMoneyTransactionForm::TransactionForm* form = dynamic_cast<KMyMoneyTransactionForm::TransactionForm*>(m_regForm);
   if(form) {
+    form->enableTabBar(false);
     KMyMoneyTransactionForm::TabBar* tabbar = new KMyMoneyTransactionForm::TabBar;
     m_editWidgets["tabbar"] = tabbar;
     tabbar->copyTabs(form->tabBar());
@@ -821,9 +876,11 @@ void StdTransactionEditor::createEditWidgets(void)
   label = new QLabel(i18n("Number"), 0);
   label->setAlignment(Qt::AlignVCenter | Qt::DontClip);
   m_editWidgets["number-label"] = label;
+
+  setupPrecision();
 }
 
-void StdTransactionEditor::setupCategoryWidget(QCString& categoryId)
+void StdTransactionEditor::setupCategoryWidget(QString& categoryId)
 {
   TransactionEditor::setupCategoryWidget(dynamic_cast<KMyMoneyCategory*>(m_editWidgets["category"]), m_splits, categoryId, SLOT(slotEditSplits()));
 
@@ -831,7 +888,7 @@ void StdTransactionEditor::setupCategoryWidget(QCString& categoryId)
     m_shares = m_splits[0].shares();
 }
 
-bool StdTransactionEditor::isTransfer(const QCString& accId1, const QCString& accId2) const
+bool StdTransactionEditor::isTransfer(const QString& accId1, const QString& accId2) const
 {
   if(accId1.isEmpty() || accId2.isEmpty())
     return false;
@@ -920,14 +977,14 @@ void StdTransactionEditor::loadEditWidgets(KMyMoneyRegister::Action action)
     }
     dynamic_cast<KMyMoneyReconcileCombo*>(m_editWidgets["status"])->setState(m_split.reconcileFlag());
 
-    QCString payeeId = m_split.payeeId();
+    QString payeeId = m_split.payeeId();
     if(!payeeId.isEmpty()) {
       payee->setSelectedItem(payeeId);
     }
 
     m_splits.clear();
     if(m_transaction.splitCount() < 2) {
-      category->completion()->setSelected(QCString());
+      category->completion()->setSelected(QString());
     } else {
       QValueList<MyMoneySplit>::const_iterator it_s;
       for(it_s = m_transaction.splits().begin(); it_s != m_transaction.splits().end(); ++it_s) {
@@ -936,7 +993,7 @@ void StdTransactionEditor::loadEditWidgets(KMyMoneyRegister::Action action)
         m_splits.append(*it_s);
       }
     }
-    QCString categoryId;
+    QString categoryId;
     setupCategoryWidget(categoryId);
 
     if((w = haveWidget("cashflow")) != 0) {
@@ -1033,7 +1090,7 @@ void StdTransactionEditor::loadEditWidgets(KMyMoneyRegister::Action action)
       w->setEnabled(false);
     }
 
-    category->completion()->setSelected(QCString());
+    category->completion()->setSelected(QString());
   }
 
   // allow kick off VAT processing again
@@ -1052,7 +1109,7 @@ void StdTransactionEditor::slotReloadEditWidgets(void)
 {
   // reload category widget
   KMyMoneyCategory* category = dynamic_cast<KMyMoneyCategory*>(m_editWidgets["category"]);
-  QCString categoryId = category->selectedItem();
+  QString categoryId = category->selectedItem();
 
   AccountSet aSet;
   aSet.addAccountGroup(MyMoneyAccount::Asset);
@@ -1074,7 +1131,7 @@ void StdTransactionEditor::slotReloadEditWidgets(void)
 
   // reload payee widget
   KMyMoneyPayeeCombo* payee = dynamic_cast<KMyMoneyPayeeCombo*>(m_editWidgets["payee"]);
-  QCString payeeId = payee->selectedItem();
+  QString payeeId = payee->selectedItem();
 
   payee->loadPayees(MyMoneyFile::instance()->payeeList());
 
@@ -1083,22 +1140,30 @@ void StdTransactionEditor::slotReloadEditWidgets(void)
   }
 }
 
-void StdTransactionEditor::slotUpdatePayee(const QCString& payeeId)
+void StdTransactionEditor::slotUpdatePayee(const QString& payeeId)
 {
   // we have a new payee assigned to this transaction.
+  // retrieve some information about the state of the category widget
+  KMyMoneyCategory* category = dynamic_cast<KMyMoneyCategory*>(m_editWidgets["category"]);
+  QStringList list;
+  category->selectedItems(list);
+
+  // If payee has associated default account (category), set that now if
+  // category is not filled
+  const MyMoneyPayee& payeeObj = MyMoneyFile::instance()->payee(payeeId);
+  if (payeeObj.defaultAccountEnabled() && list.isEmpty()) {
+    KMyMoneyCategory* category = dynamic_cast<KMyMoneyCategory*>(m_editWidgets["category"]);
+    category->slotItemSelected(payeeObj.defaultAccountId());
+    return;
+  }
+
   // in case there is no category assigned, no value entered and no
   // memo available, we search for the last transaction of this payee
   // in the account.
   if(m_transaction.id().isEmpty()
   && m_splits.count() == 0
-  && KMyMoneyGlobalSettings::autoFillTransaction()) {
-    // check if category is empty
-    KMyMoneyCategory* category = dynamic_cast<KMyMoneyCategory*>(m_editWidgets["category"]);
-    QCStringList list;
-    category->selectedItems(list);
-    if(!list.isEmpty())
-      return;
-
+  && KMyMoneyGlobalSettings::autoFillTransaction() != 0
+  && list.isEmpty()) {
     // check if memo is empty
     KTextEdit* memo = dynamic_cast<KTextEdit*>(m_editWidgets["memo"]);
     if(memo && !memo->text().isEmpty())
@@ -1149,7 +1214,12 @@ MyMoneyMoney StdTransactionEditor::shares(const MyMoneyTransaction& t) const
   return result;
 }
 
-void StdTransactionEditor::autoFill(const QCString& payeeId)
+struct uniqTransaction {
+  const MyMoneyTransaction* t;
+  int   cnt;
+};
+
+void StdTransactionEditor::autoFill(const QString& payeeId)
 {
   QValueList<QPair<MyMoneyTransaction, MyMoneySplit> >  list;
   MyMoneyTransactionFilter filter(m_account.id());
@@ -1160,23 +1230,24 @@ void StdTransactionEditor::autoFill(const QCString& payeeId)
     // what we have collected so far and add those splits from
     // the previous transaction.
     QValueList<QPair<MyMoneyTransaction, MyMoneySplit> >::const_iterator  it_t;
-    QMap<QString, const MyMoneyTransaction* > uniqList;
+    QMap<QString, struct uniqTransaction> uniqList;
 
     // collect the transactions and see if we have any duplicates
     for(it_t = list.begin(); it_t != list.end(); ++it_t) {
       QString key = (*it_t).first.accountSignature();
       int cnt = 0;
-      QMap<QString, const MyMoneyTransaction* >::iterator it_u;
+      QMap<QString, struct uniqTransaction>::iterator it_u;
       do {
         QString ukey = QString("%1-%2").arg(key).arg(cnt);
         it_u = uniqList.find(ukey);
         if(it_u == uniqList.end()) {
-          uniqList[ukey] = &((*it_t).first);
-        } else {
+          uniqList[ukey].t = &((*it_t).first);
+          uniqList[ukey].cnt = 1;
+        } else if (KMyMoneyGlobalSettings::autoFillTransaction() == 1) {
           // we already have a transaction with this signature. we must
           // now check, if we should really treat it as a duplicate according
           // to the value comparison delta.
-          MyMoneyMoney s1 = shares(*(*it_u));
+          MyMoneyMoney s1 = shares(*((*it_u).t));
           MyMoneyMoney s2 = shares((*it_t).first);
           if(s2.abs() > s1.abs()) {
             MyMoneyMoney t(s1);
@@ -1189,9 +1260,12 @@ void StdTransactionEditor::autoFill(const QCString& payeeId)
           else
             diff = ((s1 - s2) / s2).convert(10000);
           if(diff.isPositive() && diff <= MyMoneyMoney(KMyMoneyGlobalSettings::autoFillDifference(),100)) {
-            uniqList[ukey] = &((*it_t).first);
-            break;
+            uniqList[ukey].t = &((*it_t).first);
+            break;    // end while loop
           }
+        } else if (KMyMoneyGlobalSettings::autoFillTransaction() == 2) {
+          (*it_u).cnt++;
+          break;      // end while loop
         }
         ++cnt;
       } while(it_u != uniqList.end());
@@ -1199,28 +1273,48 @@ void StdTransactionEditor::autoFill(const QCString& payeeId)
     }
 
     MyMoneyTransaction t;
-    if(uniqList.count() == 1) {
-      t = list.last().first;
-    } else {
-      KSelectTransactionsDlg dlg(m_account, m_regForm);
-      dlg.setCaption(i18n("Select autofill transaction"));
+    if (KMyMoneyGlobalSettings::autoFillTransaction() != 2) {
+#if 0
+      // I removed this code to allow cancellation of an autofill if
+      // it does not match even if there is only a single matching
+      // transaction for the payee in question. In case, we want to revert
+      // to the old behavior, don't forget to uncomment the closing
+      // brace further down in the code as well. (ipwizard 2009-01-16)
+      if(uniqList.count() == 1) {
+        t = list.last().first;
+      } else {
+#endif
+        KSelectTransactionsDlg dlg(m_account, m_regForm);
+        dlg.setCaption(i18n("Select autofill transaction"));
 
-      QMap<QString, const MyMoneyTransaction*>::const_iterator it_u;
-      for(it_u = uniqList.begin(); it_u != uniqList.end(); ++it_u) {
-        dlg.addTransaction(*(*it_u));
+        QMap<QString, struct uniqTransaction>::const_iterator it_u;
+        for(it_u = uniqList.begin(); it_u != uniqList.end(); ++it_u) {
+          dlg.addTransaction(*(*it_u).t);
+        }
+
+        // setup sort order
+        dlg.m_register->setSortOrder("1,-9,-4");
+        // sort the transactions according to the sort setting
+        dlg.m_register->sortItems();
+
+        // and select the last item
+        if(dlg.m_register->lastItem())
+          dlg.m_register->selectItem(dlg.m_register->lastItem());
+
+        if(dlg.exec() == QDialog::Accepted) {
+          t = dlg.transaction();
+        }
+#if 0
       }
-
-      // setup sort order
-      dlg.m_register->setSortOrder("1,-9,-4");
-      // sort the transactions according to the sort setting
-      dlg.m_register->sortItems();
-
-      // and select the last item
-      if(dlg.m_register->lastItem())
-        dlg.m_register->selectItem(dlg.m_register->lastItem());
-
-      if(dlg.exec() == QDialog::Accepted) {
-        t = dlg.transaction();
+#endif
+    } else {
+      int maxCnt = 0;
+      QMap<QString, struct uniqTransaction>::const_iterator it_u;
+      for(it_u = uniqList.begin(); it_u != uniqList.end(); ++it_u) {
+        if((*it_u).cnt > maxCnt) {
+          t = *(*it_u).t;
+          maxCnt = (*it_u).cnt;
+        }
       }
     }
 
@@ -1239,7 +1333,7 @@ void StdTransactionEditor::autoFill(const QCString& payeeId)
         // we don't need this anymore
         if(s.action() != MyMoneySplit::ActionAmortization
         && s.action() != MyMoneySplit::ActionInterest)  {
-          s.setAction(QCString());
+          s.setAction(QString());
         }
 
         // FIXME update check number. The old comment contained
@@ -1344,7 +1438,7 @@ void StdTransactionEditor::slotUpdateCashFlow(KMyMoneyRegister::CashFlowDirectio
   }
 }
 
-void StdTransactionEditor::slotUpdateCategory(const QCString& id)
+void StdTransactionEditor::slotUpdateCategory(const QString& id)
 {
   QLabel *categoryLabel = dynamic_cast<QLabel*>(haveWidget("category-label"));
   // qDebug("Update category to %s", id.data());
@@ -1374,10 +1468,13 @@ void StdTransactionEditor::slotUpdateCategory(const QCString& id)
           tabbar->tab(KMyMoneyRegister::ActionDeposit)->setEnabled(false);
           tabbar->tab(KMyMoneyRegister::ActionWithdrawal)->setEnabled(false);
         }
-        if(val.isNegative())
-          categoryLabel->setText(i18n("Transfer from"));
-        else
-          categoryLabel->setText(i18n("Transfer to"));
+        // only change the label if an amount is already filled in
+        if(!val.isZero()) {
+          if(val.isNegative())
+            categoryLabel->setText(i18n("Transfer from"));
+          else
+            categoryLabel->setText(i18n("Transfer to"));
+        }
       } else {
         if(tabbar)
           tabbar->tab(KMyMoneyRegister::ActionTransfer)->setEnabled(false);
@@ -1449,6 +1546,7 @@ void StdTransactionEditor::updateAmount(const MyMoneyMoney& val)
           cashflow->setDirection(KMyMoneyRegister::Payment);
         else
           cashflow->setDirection(KMyMoneyRegister::Deposit);
+        slotUpdateCashFlow(cashflow->direction());
       }
       dynamic_cast<kMyMoneyEdit*>(m_editWidgets["amount"])->setValue(val.abs());
     }
@@ -1630,7 +1728,7 @@ MyMoneyMoney StdTransactionEditor::removeVatSplit(void)
   // block the signals to avoid popping up the split editor dialog
   // for nothing
   m_editWidgets["category"]->blockSignals(true);
-  QCString id;
+  QString id;
   setupCategoryWidget(id);
   m_editWidgets["category"]->blockSignals(false);
 
@@ -1641,6 +1739,11 @@ MyMoneyMoney StdTransactionEditor::removeVatSplit(void)
 bool StdTransactionEditor::isComplete(void) const
 {
   QMap<QString, QWidget*>::const_iterator it_w;
+  kMyMoneyDateInput* postDate = dynamic_cast<kMyMoneyDateInput*>(m_editWidgets["postdate"]);
+  if(postDate->date().isValid() && (postDate->date() < m_account.openingDate())) {
+    return false;
+  }
+
   for(it_w = m_editWidgets.begin(); it_w != m_editWidgets.end(); ++it_w) {
     KMyMoneyPayeeCombo* payee = dynamic_cast<KMyMoneyPayeeCombo*>(*it_w);
     KMyMoneyCategory* category = dynamic_cast<KMyMoneyCategory*>(*it_w);
@@ -1669,7 +1772,7 @@ bool StdTransactionEditor::isComplete(void) const
   return it_w != m_editWidgets.end();
 }
 
-void StdTransactionEditor::slotCreateCategory(const QString& name, QCString& id)
+void StdTransactionEditor::slotCreateCategory(const QString& name, QString& id)
 {
   MyMoneyAccount acc, parent;
   acc.setName(name);
@@ -1724,20 +1827,20 @@ int StdTransactionEditor::slotEditSplits(void)
     bool isValidAmount = false;
 
     if(amount) {
-      isValidAmount = amount->text().length() != 0;
+      isValidAmount = amount->lineedit()->text().length() != 0;
       cashflow = dynamic_cast<KMyMoneyCashFlowCombo*>(haveWidget("cashflow"));
       if(cashflow)
         dir = cashflow->direction();
 
     } else {
       if(deposit) {
-        if (deposit->text().length() != 0) {
+        if (deposit->lineedit()->text().length() != 0) {
           isValidAmount = true;
           dir = KMyMoneyRegister::Deposit;
         }
       }
       if(payment) {
-        if (payment->text().length() != 0) {
+        if (payment->lineedit()->text().length() != 0) {
           isValidAmount = true;
           dir = KMyMoneyRegister::Payment;
         }
@@ -1786,9 +1889,9 @@ int StdTransactionEditor::slotEditSplits(void)
   return rc;
 }
 
-void StdTransactionEditor::checkPayeeInSplit(MyMoneySplit& s, const QCString& payeeId)
+void StdTransactionEditor::checkPayeeInSplit(MyMoneySplit& s, const QString& payeeId)
 {
-  if(s.accountId().isEmpty() || payeeId.isEmpty())
+  if(s.accountId().isEmpty())
     return;
 
   MyMoneyAccount acc = MyMoneyFile::instance()->account(s.accountId());
@@ -1811,7 +1914,7 @@ MyMoneyMoney StdTransactionEditor::amountFromWidget(bool* update) const
     kMyMoneyEdit* amount = dynamic_cast<kMyMoneyEdit*>(m_editWidgets["amount"]);
     // if both fields do not contain changes -> no need to update
     if(cashflow->direction() != KMyMoneyRegister::Unknown
-    && !amount->text().isEmpty())
+    && !amount->lineedit()->text().isEmpty())
       updateValue = true;
     value = amount->value();
     if(cashflow->direction() == KMyMoneyRegister::Payment)
@@ -1892,7 +1995,7 @@ bool StdTransactionEditor::createTransaction(MyMoneyTransaction& t, const MyMone
   }
 
   KMyMoneyPayeeCombo* payee = dynamic_cast<KMyMoneyPayeeCombo*>(m_editWidgets["payee"]);
-  QCString payeeId;
+  QString payeeId;
   if(!isMultiSelection() || (isMultiSelection() && !payee->currentText().isEmpty())) {
     payeeId = payee->selectedItem();
     s0.setPayeeId(payeeId);
@@ -1968,8 +2071,22 @@ bool StdTransactionEditor::createTransaction(MyMoneyTransaction& t, const MyMone
     // we just copy the memo text over
     if(memo) {
       if(!isMultiSelection() || (isMultiSelection() && !memo->text().isEmpty())) {
-        if(s1.memo().isEmpty())
-          s1.setMemo(memo->text());
+        // if the memo is filled, we check if the
+        // account referenced by s1 is a regular account or a category.
+        // in case of a regular account, we just leave the memo as is
+        // in case of a category we simply copy the new value over the old.
+        // in case we don't even have an account id, we just skip because
+        // the split will be removed later on anyway.
+        if(!s1.memo().isEmpty()) {
+          if(!s1.accountId().isEmpty()) {
+            MyMoneyAccount acc = MyMoneyFile::instance()->account(s1.accountId());
+            if(acc.isIncomeExpense()) {
+              s1.setMemo(s0.memo());
+            }
+          }
+        } else {
+          s1.setMemo(s0.memo());
+        }
       }
     }
 
@@ -2015,5 +2132,14 @@ void StdTransactionEditor::setupFinalWidgets(void)
   addFinalWidget(haveWidget("status"));
 }
 
+void StdTransactionEditor::slotUpdateAccount(const QString& id)
+{
+  TransactionEditor::slotUpdateAccount(id);
+  KMyMoneyCategory* category = dynamic_cast<KMyMoneyCategory*>(m_editWidgets["category"]);
+  if(category && category->splitButton()) {
+    category->splitButton()->setDisabled(id.isEmpty());
+  }
+}
+
 #include "transactioneditor.moc"
 
