@@ -73,7 +73,7 @@ public:
     * (the default) a warning will be displayed when the balance crosses the minimum
     * or maximum balance settings for the account.
     */
-  virtual bool enterTransactions(QCString& newId, bool askForSchedule = true, bool suppressBalanceWarnings = false);
+  virtual bool enterTransactions(QString& newId, bool askForSchedule = true, bool suppressBalanceWarnings = false);
 
   /**
     * This method creates a transaction based on the contents of the current widgets,
@@ -157,13 +157,20 @@ public slots:
     *
     * @param id of the account to be used
     */
-  void slotUpdateAccount(const QCString& id);
+  void slotUpdateAccount(const QString& id);
 
 protected:
   virtual void createEditWidgets(void) = 0;
   virtual void setupFinalWidgets(void) = 0;
   virtual void loadEditWidgets(KMyMoneyRegister::Action action = KMyMoneyRegister::ActionNone) = 0;
-  void setupCategoryWidget(KMyMoneyCategory* category, const QValueList<MyMoneySplit>& splits, QCString& categoryId, const char* splitEditSlot, bool allowObjectCreation = true);
+  void setupCategoryWidget(KMyMoneyCategory* category, const QValueList<MyMoneySplit>& splits, QString& categoryId, const char* splitEditSlot, bool allowObjectCreation = true);
+
+  /**
+   * This method sets the precision of the value widgets to reflect
+   * the account in m_account. If m_account has no id, the precision
+   * defaults to 2.
+   */
+  void setupPrecision(void);
 
 protected slots:
   virtual void slotUpdateButtonState(void);
@@ -196,7 +203,7 @@ signals:
     * @param txt The name of the payee to be created
     * @param id A connected slot should store the id of the created object in this variable
     */
-  void createPayee(const QString& txt, QCString& id);
+  void createPayee(const QString& txt, QString& id);
 
   /**
     * This signal is sent out, when a new category needs to be created
@@ -259,6 +266,13 @@ signals:
    */
   void returnPressed(void);
 
+  /**
+   * This signal is sent out, if any of the balance warning levels
+   * for @p account has been reached. @p msg contains the message text.
+   * @p parent points to the parent widget to be used for the warning message box.
+   */
+  void balanceWarning(QWidget* parent, const MyMoneyAccount& account, const QString& msg);
+
 protected:
   QValueList<MyMoneySplit>                          m_splits;
   KMyMoneyRegister::SelectedTransactions            m_transactions;
@@ -270,7 +284,7 @@ protected:
   MyMoneyTransaction                                m_transaction;
   MyMoneySplit                                      m_split;
   QDate                                             m_lastPostDate;
-  QMap<QCString, MyMoneyMoney>                      m_priceInfo;
+  QMap<QString, MyMoneyMoney>                       m_priceInfo;
   KMyMoneyRegister::Action                          m_initialAction;
   bool                                              m_openEditSplits;
 };
@@ -287,6 +301,8 @@ public:
   bool isComplete(void) const;
   QWidget* firstWidget(void) const;
 
+  bool eventFilter(QObject* o, QEvent* e);
+
   /**
     * This method creates a transaction based on the contents of the current widgets,
     * the splits in m_split in single selection mode or an existing transaction/split
@@ -309,18 +325,18 @@ public:
 
 public slots:
   int slotEditSplits(void);
+  void slotUpdateAmount(const QString&);
 
 protected slots:
   void slotReloadEditWidgets(void);
   void slotUpdatePayment(const QString&);
   void slotUpdateDeposit(const QString&);
-  void slotUpdateAmount(const QString&);
-  void slotUpdateCategory(const QCString&);
-  void slotUpdatePayee(const QCString&);
+  void slotUpdateCategory(const QString&);
+  void slotUpdatePayee(const QString&);
   void slotUpdateCashFlow(KMyMoneyRegister::CashFlowDirection);
-  void slotCreateCategory(const QString&, QCString&);
+  void slotCreateCategory(const QString&, QString&);
   void slotUpdateAction(int action);
-  void slotUpdateAccount(const QCString& id);
+  void slotUpdateAccount(const QString& id);
 
 protected:
   /**
@@ -338,17 +354,17 @@ protected:
     */
   void loadEditWidgets(KMyMoneyRegister::Action action = KMyMoneyRegister::ActionNone);
 
-  void setupCategoryWidget(QCString&);
+  void setupCategoryWidget(QString&);
   void updateAmount(const MyMoneyMoney& value);
-  bool isTransfer(const QCString& accId1, const QCString& accId2) const;
+  bool isTransfer(const QString& accId1, const QString& accId2) const;
 
-  void checkPayeeInSplit(MyMoneySplit& s, const QCString& payeeId);
+  void checkPayeeInSplit(MyMoneySplit& s, const QString& payeeId);
 
   /**
     * This method fills the editor widgets with the last transaction
     * that can be found for payee @a payeeId in the account @a m_account.
     */
-  void autoFill(const QCString& payeeId);
+  void autoFill(const QString& payeeId);
 
   /**
     * Extracts the amount of the transaction from the widgets depending
