@@ -16,10 +16,11 @@
 
 // make sure, that this is defined before we even include any other header file
 #ifndef __STDC_LIMIT_MACROS
-#define __STDC_LIMIT_MACROS         // force definition of min and max values
+  #define __STDC_LIMIT_MACROS         // force definition of min and max values
 #endif
 
 #include "mymoneymoneytest.h"
+#include "mymoneyexception.h"
 #include <iostream>
 #include <stdint.h>
 
@@ -40,7 +41,7 @@ void MyMoneyMoneyTest::setUp()
   m_0 = new MyMoneyMoney(12);
   m_1 = new MyMoneyMoney(-10);
   m_2 = new MyMoneyMoney(2);
-  m_3 = new MyMoneyMoney(123,0);
+  m_3 = new MyMoneyMoney(123,1);
   m_4 = new MyMoneyMoney(1234,1000);
   m_5 = new MyMoneyMoney(195883,100000);
 
@@ -165,6 +166,11 @@ void MyMoneyMoneyTest::testStringConstructor()
   CPPUNIT_ASSERT(m1->m_num == LLCONST(-1234567));
   CPPUNIT_ASSERT(m1->m_denom == 1000);
   delete m1;
+
+  m1 = new MyMoneyMoney("1 5/8");
+  CPPUNIT_ASSERT(m1->m_num == LLCONST(13));
+  CPPUNIT_ASSERT(m1->m_denom == 8);
+  delete m1;
 }
 
 void MyMoneyMoneyTest::testConvert()
@@ -319,12 +325,12 @@ void MyMoneyMoneyTest::testSetDecimalSeparator()
   MyMoneyMoney m1(100000);
   MyMoneyMoney m2(200000);
 
-  CPPUNIT_ASSERT(m1.formatMoney() == QString("1,000.00"));
+  CPPUNIT_ASSERT(m1.formatMoney("", 2) == QString("1,000.00"));
   CPPUNIT_ASSERT(MyMoneyMoney::decimalSeparator() == '.');
 
   MyMoneyMoney::setDecimalSeparator(':');
-  CPPUNIT_ASSERT(m1.formatMoney() == QString("1,000:00"));
-  CPPUNIT_ASSERT(m2.formatMoney() == QString("2,000:00"));
+  CPPUNIT_ASSERT(m1.formatMoney("", 2) == QString("1,000:00"));
+  CPPUNIT_ASSERT(m2.formatMoney("", 2) == QString("2,000:00"));
 
   CPPUNIT_ASSERT(MyMoneyMoney::decimalSeparator() == ':');
 }
@@ -334,41 +340,57 @@ void MyMoneyMoneyTest::testSetThousandSeparator()
   MyMoneyMoney m1(100000);
   MyMoneyMoney m2(200000);
 
-  CPPUNIT_ASSERT(m1.formatMoney() == QString("1,000.00"));
+  CPPUNIT_ASSERT(m1.formatMoney("", 2) == QString("1,000.00"));
   CPPUNIT_ASSERT(MyMoneyMoney::thousandSeparator() == ',');
 
   MyMoneyMoney::setThousandSeparator(':');
-  CPPUNIT_ASSERT(m1.formatMoney() == QString("1:000.00"));
-  CPPUNIT_ASSERT(m2.formatMoney() == QString("2:000.00"));
+  CPPUNIT_ASSERT(m1.formatMoney("", 2) == QString("1:000.00"));
+  CPPUNIT_ASSERT(m2.formatMoney("", 2) == QString("2:000.00"));
 
   CPPUNIT_ASSERT(MyMoneyMoney::thousandSeparator() == ':');
 }
 
 void MyMoneyMoneyTest::testFormatMoney()
 {
-  CPPUNIT_ASSERT(m_0->formatMoney() == QString("0.12"));
-  CPPUNIT_ASSERT(m_1->formatMoney() == QString("-0.10"));
+  CPPUNIT_ASSERT(m_0->formatMoney("", 2) == QString("0.12"));
+  CPPUNIT_ASSERT(m_1->formatMoney("", 2) == QString("-0.10"));
 
   MyMoneyMoney m1(10099);
-  CPPUNIT_ASSERT(m1.formatMoney() == QString("100.99"));
+  CPPUNIT_ASSERT(m1.formatMoney("", 2) == QString("100.99"));
 
   m1 = MyMoneyMoney(100,1);
-  CPPUNIT_ASSERT(m1.formatMoney() == QString("100.00"));
+  CPPUNIT_ASSERT(m1.formatMoney("", 2) == QString("100.00"));
+  CPPUNIT_ASSERT(m1.formatMoney("", -1) == QString("100"));
 
   m1 = m1 * 10;
-  CPPUNIT_ASSERT(m1.formatMoney() == QString("1,000.00"));
+  CPPUNIT_ASSERT(m1.formatMoney("", 2) == QString("1,000.00"));
+  CPPUNIT_ASSERT(m1.formatMoney("", -1) == QString("1,000"));
+  CPPUNIT_ASSERT(m1.formatMoney("", -1, false) == QString("1000"));
+  CPPUNIT_ASSERT(m1.formatMoney("", 3, false) == QString("1000.000"));
 
   m1 = MyMoneyMoney(INT64_MAX, 100);
-  CPPUNIT_ASSERT(m1.formatMoney() == QString("92,233,720,368,547,758.07"));
+  CPPUNIT_ASSERT(m1.formatMoney("", 2) == QString("92,233,720,368,547,758.07"));
+  CPPUNIT_ASSERT(m1.formatMoney(100) == QString("92,233,720,368,547,758.07"));
+  CPPUNIT_ASSERT(m1.formatMoney("", 2, false) == QString("92233720368547758.07"));
+  CPPUNIT_ASSERT(m1.formatMoney(100, false) == QString("92233720368547758.07"));
 
   m1 = MyMoneyMoney(INT64_MIN, 100);
-  CPPUNIT_ASSERT(m1.formatMoney() == QString("-92,233,720,368,547,758.08"));
+  CPPUNIT_ASSERT(m1.formatMoney("", 2) == QString("-92,233,720,368,547,758.08"));
+  CPPUNIT_ASSERT(m1.formatMoney(100) == QString("-92,233,720,368,547,758.08"));
+  CPPUNIT_ASSERT(m1.formatMoney("", 2, false) == QString("-92233720368547758.08"));
+  CPPUNIT_ASSERT(m1.formatMoney(100, false) == QString("-92233720368547758.08"));
 
   m1 = MyMoneyMoney(1,5);
-  CPPUNIT_ASSERT(m1.formatMoney() == QString("0.20"));
+  CPPUNIT_ASSERT(m1.formatMoney("", 2) == QString("0.20"));
+  CPPUNIT_ASSERT(m1.formatMoney(1000) == QString("0.200"));
+  CPPUNIT_ASSERT(m1.formatMoney(100) == QString("0.20"));
+  CPPUNIT_ASSERT(m1.formatMoney(10) == QString("0.2"));
 
   m1 = MyMoneyMoney(13333,5000);
   CPPUNIT_ASSERT(m1.formatMoney("", 10) == QString("2.6666000000"));
+
+  m1 = MyMoneyMoney(-1404,100);
+  CPPUNIT_ASSERT(m1.formatMoney("",-1) == QString("-14.04"));
 }
 
 void MyMoneyMoneyTest::testRelation()
@@ -529,3 +551,59 @@ void MyMoneyMoneyTest::testPositiveSignPos(void)
   MyMoneyMoney::setPositiveMonetarySignPosition(pos);
 }
 
+void MyMoneyMoneyTest::testNegativeStringConstructor(void)
+{
+  MyMoneyMoney *m1;
+  MyMoneyMoney::setDecimalSeparator(',');
+  MyMoneyMoney::setThousandSeparator('.');
+  MyMoneyMoney::setNegativeMonetarySignPosition(MyMoneyMoney::ParensAround);
+  m1 = new MyMoneyMoney("x(1.234,567) EUR");
+  CPPUNIT_ASSERT(m1->m_num == LLCONST(-1234567));
+  CPPUNIT_ASSERT(m1->m_denom == 1000);
+  delete m1;
+  MyMoneyMoney::setNegativeMonetarySignPosition(MyMoneyMoney::BeforeQuantityMoney);
+  m1 = new MyMoneyMoney("x1.234,567- EUR");
+  CPPUNIT_ASSERT(m1->m_num == LLCONST(-1234567));
+  CPPUNIT_ASSERT(m1->m_denom == 1000);
+  delete m1;
+  m1 = new MyMoneyMoney("x1.234,567 -EUR");
+  CPPUNIT_ASSERT(m1->m_num == LLCONST(-1234567));
+  CPPUNIT_ASSERT(m1->m_denom == 1000);
+  delete m1;
+  m1 = new MyMoneyMoney("-1.234,567 EUR");
+  CPPUNIT_ASSERT(m1->m_num == LLCONST(-1234567));
+  CPPUNIT_ASSERT(m1->m_denom == 1000);
+  delete m1;
+}
+
+void MyMoneyMoneyTest::testReduce(void)
+{
+  MyMoneyMoney a(36488100, 1267390000);
+  MyMoneyMoney b(-a);
+
+  a = a.reduce();
+  CPPUNIT_ASSERT(a.m_num == 364881);
+  CPPUNIT_ASSERT(a.m_denom == 12673900);
+
+  b = b.reduce();  
+  CPPUNIT_ASSERT(b.m_num == -364881);
+  CPPUNIT_ASSERT(b.m_denom == 12673900);
+}
+
+void MyMoneyMoneyTest::testZeroDenominator()
+{
+  try {
+    MyMoneyMoney m((int)1, 0);
+    CPPUNIT_FAIL("Missing expected exception");
+  } catch(MyMoneyException *e) {
+    delete e;
+  }
+
+  try {
+    MyMoneyMoney m((signed64)1, 0);
+    CPPUNIT_FAIL("Missing expected exception");
+  } catch(MyMoneyException *e) {
+    delete e;
+  }
+}
+
