@@ -37,7 +37,7 @@ MyMoneyPayee::MyMoneyPayee() :
 {
 }
 
-MyMoneyPayee::MyMoneyPayee(const QCString& id, const MyMoneyPayee& payee) :
+MyMoneyPayee::MyMoneyPayee(const QString& id, const MyMoneyPayee& payee) :
   m_matchingEnabled(false),
   m_usingMatchKey(false),
   m_matchKeyIgnoreCase(true)
@@ -65,8 +65,9 @@ MyMoneyPayee::MyMoneyPayee(const QString& name, const QString& address,
 MyMoneyPayee::MyMoneyPayee(const QDomElement& node) :
   MyMoneyObject(node)
 {
-  if("PAYEE" != node.tagName())
+  if ("PAYEE" != node.tagName()) {
     throw new MYMONEYEXCEPTION("Node was not PAYEE");
+  }
 
   m_name = node.attribute("name");
   m_reference = node.attribute("reference");
@@ -84,6 +85,10 @@ MyMoneyPayee::MyMoneyPayee(const QDomElement& node) :
     m_notes = node.attribute("notes");
   }
 
+  if (node.hasAttribute("defaultaccountid")) {
+    m_defaultAccountId = node.attribute("defaultaccountid");
+  }
+
   QDomNodeList nodeList = node.elementsByTagName("ADDRESS");
   if(nodeList.count() == 0) {
     QString msg = QString("No ADDRESS in payee %1").arg(m_name);
@@ -122,7 +127,8 @@ bool MyMoneyPayee::operator == (const MyMoneyPayee& right) const
       (m_usingMatchKey == right.m_usingMatchKey) &&
       (m_matchKeyIgnoreCase == right.m_matchKeyIgnoreCase) &&
       ((m_matchKey.length() == 0 && right.m_matchKey.length() == 0) || m_matchKey == right.m_matchKey) &&
-      ((m_reference.length() == 0 && right.m_reference.length() == 0) || (m_reference == right.m_reference)) );
+      ((m_reference.length() == 0 && right.m_reference.length() == 0) || (m_reference == right.m_reference)) &&
+      ((m_defaultAccountId.length() == 0 && right.m_defaultAccountId.length() == 0) || m_defaultAccountId == right.m_defaultAccountId) );
 }
 
 void MyMoneyPayee::writeXML(QDomDocument& document, QDomElement& parent) const
@@ -145,6 +151,10 @@ void MyMoneyPayee::writeXML(QDomDocument& document, QDomElement& parent) const
     el.setAttribute("matchkey", m_matchKey);
   }
 
+  if (!m_defaultAccountId.isEmpty()) {
+    el.setAttribute("defaultaccountid", m_defaultAccountId);
+  }
+
   QDomElement address = document.createElement("ADDRESS");
   address.setAttribute("street", m_address);
   address.setAttribute("city", m_city);
@@ -157,12 +167,10 @@ void MyMoneyPayee::writeXML(QDomDocument& document, QDomElement& parent) const
   parent.appendChild(el);
 }
 
-bool MyMoneyPayee::hasReferenceTo(const QCString& id) const
+bool MyMoneyPayee::hasReferenceTo(const QString& id) const
 {
-  Q_UNUSED(id);
+  return id == m_defaultAccountId;
 
-  // the payee does not reference any other object
-  return false;
 }
 
 MyMoneyPayee::payeeMatchType MyMoneyPayee::matchData(bool& ignorecase, QStringList& keys) const
@@ -182,6 +190,14 @@ MyMoneyPayee::payeeMatchType MyMoneyPayee::matchData(bool& ignorecase, QStringLi
   return type;
 }
 
+MyMoneyPayee::payeeMatchType MyMoneyPayee::matchData(bool& ignorecase, QString& keyString) const
+{
+  QStringList keys;
+  payeeMatchType type = matchData(ignorecase, keys);
+  keyString = keys.join(";");
+  return type;
+}
+
 void MyMoneyPayee::setMatchData(payeeMatchType type, bool ignorecase, const QStringList& keys)
 {
   m_matchingEnabled = (type != matchDisabled);
@@ -197,4 +213,10 @@ void MyMoneyPayee::setMatchData(payeeMatchType type, bool ignorecase, const QStr
     m_matchKeyIgnoreCase = ignorecase;
   }
 }
+
+void MyMoneyPayee::setMatchData(payeeMatchType type, bool ignorecase, const QString& keys)
+{
+  setMatchData(type, ignorecase, QStringList::split(";", keys));
+}
+
 // vim:cin:si:ai:et:ts=2:sw=2:
