@@ -41,6 +41,8 @@
 #include "mymoneymoney.h"
 #include <kmymoney/export.h>
 #include <kmymoney/mymoneyobject.h>
+#include <kmymoney/mymoneykeyvaluecontainer.h>
+class MyMoneyTransaction;
 
 /**
   * @author Thomas Baumgart
@@ -49,7 +51,7 @@
 /**
   * This class represents a split of a transaction.
   */
-class KMYMONEY_EXPORT MyMoneySplit : public MyMoneyObject
+class KMYMONEY_EXPORT MyMoneySplit : public MyMoneyObject, public MyMoneyKeyValueContainer
 {
 public:
   /**
@@ -91,7 +93,7 @@ public:
 
   MyMoneySplit();
   MyMoneySplit(const QDomElement& node);
-  MyMoneySplit(const QCString& id, const MyMoneySplit& right);
+  MyMoneySplit(const QString& id, const MyMoneySplit& right);
   ~MyMoneySplit();
 
   bool operator == (const MyMoneySplit&) const;
@@ -107,7 +109,7 @@ public:
     * @retval true This object references object with id @p id.
     * @retval false This object does not reference the object with id @p id.
     */
-  virtual bool hasReferenceTo(const QCString& id) const;
+  virtual bool hasReferenceTo(const QString& id) const;
 
   const MyMoneyMoney& shares(void) const { return m_shares; }
   const MyMoneyMoney& value(void) const { return m_value; }
@@ -119,19 +121,35 @@ public:
    * will be returned.
    */
   MyMoneyMoney price(void) const;
+  /** This method just returns what is in m_price, so when we write to the
+   *  database, we don't just generate prices
+  */
+  MyMoneyMoney actualPrice(void) const { return m_price; }
 
-  MyMoneyMoney value(const QCString& transactionCurrencyId, const QCString& splitCurrencyId) const;
-  const QCString& accountId(void) const { return m_account; }
+  const MyMoneyMoney value(const QString& transactionCurrencyId, const QString& splitCurrencyId) const;
+
+  /**
+   * Required to have (direct) access to the MyMoneyKeyValueContainer::value() method.
+   */
+  const QString& value(const QString& key) const { return MyMoneyKeyValueContainer::value(key); }
+
+  /**
+   * Required to have (direct) access to the MyMoneyKeyValueContainer::setValue() method.
+   */
+  void setValue(const QString& key, const QString& value) { MyMoneyKeyValueContainer::setValue(key, value); }
+
+  const QString& accountId(void) const { return m_account; }
   const QString& memo(void) const { return m_memo; }
   reconcileFlagE reconcileFlag(void) const { return m_reconcileFlag; }
   const QDate& reconcileDate(void) const { return m_reconcileDate; }
-  const QCString& payeeId(void) const { return m_payee; }
-  const QCString& action(void) const { return m_action; }
+  const QString& payeeId(void) const { return m_payee; }
+  const QString& action(void) const { return m_action; }
   const QString& number(void) const { return m_number; }
   bool isAmortizationSplit(void) const { return m_action == ActionAmortization; }
+  bool isInterestSplit(void) const { return m_action == ActionInterest; }
   bool isAutoCalc(void) const { return (m_shares == MyMoneyMoney::autoCalc) || (m_value == MyMoneyMoney::autoCalc); }
   const QString& bankID(void) const { return m_bankID; }
-  const QCString& transactionId(void) const { return m_transactionId; }
+  const QString& transactionId(void) const { return m_transactionId; }
 
   void setShares(const MyMoneyMoney& shares);
   void setValue(const MyMoneyMoney& value);
@@ -150,18 +168,43 @@ public:
     *                        the id of the currency assigned to the account that is
     *                        referenced by the split)
     */
-  void setValue(const MyMoneyMoney& value, const QCString& transactionCurrencyId, const QCString& splitCurrencyId);
+  void setValue(const MyMoneyMoney& value, const QString& transactionCurrencyId, const QString& splitCurrencyId);
 
-  void setAccountId(const QCString& account);
+  void setAccountId(const QString& account);
   void setMemo(const QString& memo);
   void setReconcileFlag(const reconcileFlagE flag);
-  void setReconcileDate(const QDate date);
-  void setPayeeId(const QCString& payee);
-  void setAction(const QCString& action);
+  void setReconcileDate(const QDate& date);
+  void setPayeeId(const QString& payee);
+  void setAction(const QString& action);
   void setAction(investTransactionTypeE type);
   void setNumber(const QString& number);
   void setBankID(const QString& bankID) { m_bankID = bankID; };
-  void setTransactionId(const QCString& id) { m_transactionId = id; }
+  void setTransactionId(const QString& id) { m_transactionId = id; }
+
+    /**
+   * returns @a true if this its a transaction matched against an imported
+   * transaction. The imported and matched transaction can be extracted
+   * using matchedTransaction() and can be removed using removeMatch().
+     */
+  bool isMatched(void) const;
+
+  /**
+   * add an imported transaction @p t as matching transaction. Any previously
+   * added transaction will be overridden. @p t.isImported() must return true,
+   * otherwise the transaction is not stored.
+   */
+  void addMatch(const MyMoneyTransaction& t);
+
+  /**
+   * remove the data of the imported transaction added with addMatch().
+   */
+  void removeMatch(void);
+
+  /**
+   * Return the matching imported transaction. If no such transaction
+   * is available (isMatched() returns false) an empty transaction is returned.
+   */
+  MyMoneyTransaction matchedTransaction(void) const;
 
   static const char ActionCheck[];
   static const char ActionDeposit[];
@@ -183,17 +226,17 @@ private:
   /**
     * This member contains the ID of the transaction
     */
-  QCString      m_id;
+  QString      m_id;
 
   /**
     * This member contains the ID of the payee
     */
-  QCString      m_payee;
+  QString      m_payee;
 
   /**
     * This member contains the ID of the account
     */
-  QCString      m_account;
+  QString      m_account;
 
   /**
     */
@@ -236,7 +279,7 @@ private:
     * be conveniently limited to a menu of selections such as
     * "Buy", "Sell", "Interest", etc.
     */
-  QCString      m_action;
+  QString      m_action;
 
   /**
     * The m_number member is used to store a reference number to
@@ -258,7 +301,7 @@ private:
     * split can be found in. It is the purpose of the MyMoneyTransaction
     * object to maintain this member variable.
     */
-  QCString      m_transactionId;
+  QString      m_transactionId;
 };
 
 #endif
