@@ -37,6 +37,7 @@
 #include "../mymoney/mymoneyreport.h"
 #include "../mymoney/mymoneyexception.h"
 #include "../kmymoneyutils.h"
+#include "../kmymoneyglobalsettings.h"
 #include "reportdebug.h"
 #include "listtable.h"
 
@@ -153,6 +154,18 @@ namespace reports {
     csv = "";
     result += QString ( "<h2 class=\"report\">%1</h2>\n" ).arg ( m_config.name() );
     csv += "\"Report: " + m_config.name() + "\"\n";
+      //actual dates of the report
+    result += QString("<div class=\"subtitle\">");
+    if(!m_config.fromDate().isNull()) {
+      result += i18n("Report date range", "%1 through %2").arg(KGlobal::locale()->formatDate(m_config.fromDate(), true)).arg(KGlobal::locale()->formatDate(m_config.toDate(), true));
+      result += QString("</div>\n");
+      result += QString("<div class=\"gap\">&nbsp;</div>\n");
+
+      csv += i18n("Report date range", "%1 through %2").arg(KGlobal::locale()->formatDate(m_config.fromDate(), true)).arg(KGlobal::locale()->formatDate(m_config.toDate(), true));
+      csv += QString("\n");
+    }
+
+
     result += QString ( "<div class=\"subtitle\">" );
     if ( m_config.isConvertCurrency() )
     {
@@ -533,7 +546,7 @@ namespace reports {
           grandtotal += ( *it_group ).subtotal();
           grandtotal = grandtotal.convert(fraction);
         }
-        
+
 
         QString subtotal_html = ( *it_group ).subtotal().formatMoney ( fraction );
         QString subtotal_csv = ( *it_group ).subtotal().formatMoney ( fraction, false );
@@ -590,4 +603,27 @@ namespace reports {
     g.close();
   }
 
+  void ListTable::includeInvestmentSubAccounts()
+  {
+  // if we're not in expert mode, we need to make sure
+  // that all stock accounts for the selected investment
+  // account are also selected
+    QStringList accountList;
+    if(m_config.accounts(accountList)) {
+      if(!KMyMoneyGlobalSettings::expertMode()) {
+        QStringList::const_iterator it_a, it_b;
+        for(it_a = accountList.begin(); it_a != accountList.end(); ++it_a) {
+          MyMoneyAccount acc = MyMoneyFile::instance()->account(*it_a);
+          if(acc.accountType() == MyMoneyAccount::Investment) {
+            for(it_b = acc.accountList().begin(); it_b != acc.accountList().end(); ++it_b) {
+              if(!accountList.contains(*it_b)) {
+                m_config.addAccount(*it_b);
+              }
+            }
+          }
+        }
+      }
+    }
+  }
+
 }
