@@ -21,6 +21,7 @@
 
 // ----------------------------------------------------------------------------
 // QT Includes
+
 #include <qmap.h>
 #include <qvaluelist.h>
 
@@ -29,14 +30,12 @@
 
 // ----------------------------------------------------------------------------
 // Project Includes
-//#include "../mymoney/mymoneyfile.h"
-//#include "../mymoney/mymoneyreport.h"
-//#include "reporttable.h"
+
 #include "reportaccount.h"
 
 namespace reports {
 
-  enum ERowType {eActual, eBudget, eBudgetDiff, eForecast };
+  enum ERowType {eActual, eBudget, eBudgetDiff, eForecast, eAverage, ePrice };
 
   /**
     * The fundamental data construct of this class is a 'grid'.  It is organized as follows:
@@ -137,7 +136,13 @@ namespace reports {
     // default sort order
     static const unsigned m_kDefaultSortOrder;
   };
-  class PivotGrid: public QMap<QString,PivotOuterGroup> { public: PivotGridRowSet m_total; };
+  class PivotGrid: public QMap<QString,PivotOuterGroup>
+  {
+    public:
+      PivotGridRowSet rowSet (QString id);
+
+      PivotGridRowSet m_total;
+  };
 
 }
 
