@@ -39,6 +39,8 @@
 #include <qpainter.h>
 #include <qheader.h>
 #include <qbuttongroup.h>
+#include <qsplitter.h>
+#include <qmap.h>
 
 // ----------------------------------------------------------------------------
 // KDE Includes
@@ -52,6 +54,7 @@
 #include <kstandarddirs.h>
 #include <kdebug.h>
 #include <kapplication.h>
+#include <keditlistbox.h>
 
 // ----------------------------------------------------------------------------
 // Project Includes
@@ -67,15 +70,6 @@
 /*                               KTransactionPtrVector                            */
 /* -------------------------------------------------------------------------------*/
 
-int KTransactionPtrVector::compareItems(const QCString& s1, const QCString& s2) const
-{
-  if(s1 == s2)
-    return 0;
-  if(s1 < s2)
-    return -1;
-  return 1;
-}
-
 int KTransactionPtrVector::compareItems(const QString& s1, const QString& s2) const
 {
   if(s1 == s2)
@@ -251,13 +245,13 @@ void KTransactionPtrVector::setSortType(const TransactionSortE type)
   sort();
 }
 
-void KTransactionPtrVector::setAccountId(const QCString& id)
+void KTransactionPtrVector::setAccountId(const QString& id)
 {
   m_id = id;
   m_idMode = AccountMode;
 }
 
-void KTransactionPtrVector::setPayeeId(const QCString& id)
+void KTransactionPtrVector::setPayeeId(const QString& id)
 {
   m_id = id;
   m_idMode = PayeeMode;
@@ -293,7 +287,7 @@ void KPayeeListItem::paintCell(QPainter *p, const QColorGroup & cg, int column,
   QListViewItem::paintCell(p, cg2, column, width, align);
 }
 
-KTransactionListItem::KTransactionListItem(KListView* view, KTransactionListItem* parent, const QCString& accountId, const QCString& transactionId) :
+KTransactionListItem::KTransactionListItem(KListView* view, KTransactionListItem* parent, const QString& accountId, const QString& transactionId) :
   KListViewItem(view, parent)
 {
   m_accountId = accountId;
@@ -331,7 +325,22 @@ KPayeesView::KPayeesView(QWidget *parent, const char *name ) :
   // create the searchline widget
   // and insert it into the existing layout
   m_searchWidget = new KListViewSearchLineWidget(m_payeesList, this);
-  KPayeesViewDeclLayout->insertWidget(2, m_searchWidget);
+  m_searchWidget->setSizePolicy(QSizePolicy(QSizePolicy::Preferred, QSizePolicy::Fixed));
+  KPayeesViewDeclLayout->insertWidget(0, m_searchWidget);
+
+  m_splitter = new QSplitter(this);
+  m_payeesList->reparent(m_splitter, QPoint(0,0), true);
+  m_tabWidget->reparent(m_splitter, QPoint(0, 0), true);
+  m_splitter->setResizeMode(m_tabWidget, QSplitter::Stretch);
+  m_splitter->setOpaqueResize();
+  layout10->addWidget(m_splitter);
+
+  // use the size settings of the last run (if any)
+  KConfig *config = KGlobal::config();
+  config->setGroup("Last Use Settings");
+  QValueList<int> sizes = config->readIntListEntry("KPayeesViewSplitterSize");
+  if(sizes.size() == 2)
+    m_splitter->setSizes(sizes);
 
   m_transactionView->setSorting(-1);
   m_transactionView->setColumnWidthMode(2, QListView::Manual);
@@ -342,12 +351,16 @@ KPayeesView::KPayeesView(QWidget *parent, const char *name ) :
   m_payeesList->addColumn(i18n("Name"));
 
   m_updateButton->setEnabled(false);
+  radioNoMatch->setChecked(true);
 
-  matchKeyEdit->setEnabled(false);
   checkMatchIgnoreCase->setEnabled(false);
 
+  checkEnableDefaultAccount->setChecked(false);
+  labelDefaultAccount->setEnabled(false);
+  comboDefaultAccount->setEnabled(false);
+
   KIconLoader* il = KGlobal::iconLoader();
-  KGuiItem updateButtenItem( "",
+  KGuiItem updateButtenItem( i18n("Update"),
                     QIconSet(il->loadIcon("button_ok", KIcon::Small, KIcon::SizeSmall)),
                     i18n("Accepts the entered data and stores it"),
                     i18n("Use this to accept the modified data."));
@@ -360,14 +373,20 @@ KPayeesView::KPayeesView(QWidget *parent, const char *name ) :
   connect(postcodeEdit, SIGNAL(textChanged(const QString&)), this, SLOT(slotPayeeDataChanged()));
   connect(telephoneEdit, SIGNAL(textChanged(const QString&)), this, SLOT(slotPayeeDataChanged()));
   connect(emailEdit, SIGNAL(textChanged(const QString&)), this, SLOT(slotPayeeDataChanged()));
+  connect(notesEdit, SIGNAL(textChanged()), this, SLOT(slotPayeeDataChanged()));
+  connect(matchKeyEditList, SIGNAL(changed()), this, SLOT(slotKeyListChanged()));
 
   connect(radioNoMatch, SIGNAL(toggled(bool)), this, SLOT(slotPayeeDataChanged()));
   connect(radioNameMatch, SIGNAL(toggled(bool)), this, SLOT(slotPayeeDataChanged()));
   connect(radioKeyMatch, SIGNAL(toggled(bool)), this, SLOT(slotPayeeDataChanged()));
   connect(checkMatchIgnoreCase, SIGNAL(toggled(bool)), this, SLOT(slotPayeeDataChanged()));
 
-  connect(m_updateButton, SIGNAL(pressed()), this, SLOT(slotUpdatePayee()));
-  connect(m_helpButton, SIGNAL(pressed()), this, SLOT(slotHelp()));
+  connect(checkEnableDefaultAccount, SIGNAL(toggled(bool)), this, SLOT(slotPayeeDataChanged()));
+  connect(comboDefaultAccount, SIGNAL(accountSelected(const QString&)), this, SLOT(slotPayeeDataChanged()));
+  connect(buttonSelectMyAccount, SIGNAL(clicked()), this, SLOT(slotChooseDefaultAccount()));
+
+  connect(m_updateButton, SIGNAL(clicked()), this, SLOT(slotUpdatePayee()));
+  connect(m_helpButton, SIGNAL(clicked()), this, SLOT(slotHelp()));
 
   connect(m_payeesList, SIGNAL(contextMenu(KListView*, QListViewItem*, const QPoint&)), this, SLOT(slotOpenContextMenu(KListView*, QListViewItem*, const QPoint&)));
 
@@ -384,6 +403,10 @@ KPayeesView::KPayeesView(QWidget *parent, const char *name ) :
 
 KPayeesView::~KPayeesView()
 {
+  // remember the splitter settings for startup
+  KConfig *config = KGlobal::config();
+  config->setGroup("Last Use Settings");
+  config->writeEntry("KPayeesViewSplitterSize", m_splitter->sizes());
 }
 
 void KPayeesView::slotQueueUpdate(void)
@@ -401,6 +424,45 @@ void KPayeesView::slotActivateUpdate(void)
     slotSelectPayee();
 }
 
+void KPayeesView::slotChooseDefaultAccount(void)
+{
+    MyMoneyFile* file = MyMoneyFile::instance();
+    QMap<QString,int> account_count;
+
+  for (int i = 0; i < m_transactionPtrVector.size(); ++i) {
+    KMyMoneyTransaction* t = m_transactionPtrVector[i];
+    MyMoneySplit s = t->splitById(t->splitId());
+    const MyMoneyAccount& acc = file->account(s.accountId());
+
+    QString txt;
+    if (s.action() != MyMoneySplit::ActionAmortization
+        && acc.accountType() != MyMoneyAccount::AssetLoan
+        && !file->isTransfer(*t)
+        && t->splitCount() == 2) {
+      MyMoneySplit s0 = t->splitByAccount(s.accountId(), false);
+      if (account_count.contains(s0.accountId())) {
+        account_count[s0.accountId()]++;
+      }
+      else {
+        account_count[s0.accountId()] = 1;
+      }
+    }
+  }
+
+  QMapIterator<QString,int> most_frequent, iter;
+  most_frequent = account_count.end();
+  for (iter = account_count.begin(); iter != account_count.end(); iter++) {
+    if (iter.data() > most_frequent.data()) {
+      most_frequent = iter;
+    }
+  }
+
+  if (most_frequent != account_count.end()) {
+    checkEnableDefaultAccount->setChecked(true);
+    comboDefaultAccount->setSelected(most_frequent.key());
+  }
+}
+
 void KPayeesView::slotStartRename(void)
 {
   QListViewItemIterator it_l(m_payeesList, QListViewItemIterator::Selected);
@@ -463,7 +525,7 @@ void KPayeesView::slotRenamePayee(QListViewItem* p , int /* col */, const QStrin
   }
 }
 
-void KPayeesView::ensurePayeeVisible(const QCString& id)
+void KPayeesView::ensurePayeeVisible(const QString& id)
 {
   for (QListViewItem * item = m_payeesList->firstChild(); item; item = item->itemBelow()) {
     KPayeeListItem* p = dynamic_cast<KPayeeListItem*>(item);
@@ -514,14 +576,17 @@ void KPayeesView::slotSelectPayee(void)
 
   emit selectObjects(payeesList);
 
-  if (payeesList.count() == 0)
+  if (payeesList.count() == 0) {
+    m_tabWidget->setEnabled(false); // disable tab widget
+    clearItemData();
+    m_payee = MyMoneyPayee();
     return; // make sure we don't access an undefined payee
+  }
 
   // if we have multiple payees selected, clear and disable the payee informations
   if (payeesList.count() > 1) {
-    m_tabWidget->setCurrentPage(0); // activate transaction view
-    m_transactionView->clear();     // clear transaction view
     m_tabWidget->setEnabled(false); // disable tab widget
+    clearItemData();
     // disable renaming in all listviewitem
     for (QListViewItem * i = m_payeesList->firstChild(); i; i = i->itemBelow())
       i->setRenameEnabled(0, false);
@@ -548,14 +613,20 @@ void KPayeesView::slotSelectPayee(void)
     telephoneEdit->setText(m_payee.telephone());
     emailEdit->setEnabled(true);
     emailEdit->setText(m_payee.email());
+    notesEdit->setText(m_payee.notes());
 
-    QString key;
+    QStringList keys;
     bool ignorecase = false;
-    MyMoneyPayee::payeeMatchType type = m_payee.matchData(ignorecase, key);
+    MyMoneyPayee::payeeMatchType type = m_payee.matchData(ignorecase, keys);
 
     m_matchType->setButton(static_cast<int>(type));
-    matchKeyEdit->setText(key);
+    matchKeyEditList->clear();
+    matchKeyEditList->insertStringList(keys);
     checkMatchIgnoreCase->setChecked(ignorecase);
+
+    checkEnableDefaultAccount->setChecked(m_payee.defaultAccountEnabled());
+    comboDefaultAccount->setSelected(m_payee.defaultAccountId());
+
     slotPayeeDataChanged();
 
     showTransactions();
@@ -568,6 +639,16 @@ void KPayeesView::slotSelectPayee(void)
   }
 }
 
+void KPayeesView::clearItemData(void)
+{
+  addressEdit->setText(QString());
+  postcodeEdit->setText(QString());
+  telephoneEdit->setText(QString());
+  emailEdit->setText(QString());
+  notesEdit->setText(QString());
+  showTransactions();
+}
+
 void KPayeesView::showTransactions(void)
 {
   MyMoneyFile* file = MyMoneyFile::instance();
@@ -577,7 +658,7 @@ void KPayeesView::showTransactions(void)
   // clear the current transaction listview
   m_transactionView->clear();
 
-  if(m_payee.id().isEmpty()) {
+  if(m_payee.id().isEmpty() || !m_tabWidget->isEnabled()) {
     m_balanceLabel->setText(i18n("Balance: %1").arg(balance.formatMoney(MyMoneyFile::instance()->baseCurrency().smallestAccountFraction())));
     return;
   }
@@ -596,13 +677,13 @@ void KPayeesView::showTransactions(void)
   m_transactionPtrVector.setSortType(KTransactionPtrVector::SortPostDate);
 
   QValueList<MyMoneyTransaction>::ConstIterator it_t;
-  QCString lastId;
+  QString lastId;
   int ofs = 0;
 
   for(i = 0, it_t = list.begin(); it_t != list.end(); ++it_t) {
     KMyMoneyTransaction k(*it_t);
 
-    filter.match(*it_t, MyMoneyFile::instance()->storage());
+    filter.match(*it_t);
     if(lastId != (*it_t).id()) {
       ofs = 0;
       lastId = (*it_t).id();
@@ -654,7 +735,7 @@ void KPayeesView::showTransactions(void)
       } else {
         txt = i18n("Loan payment from %1").arg(acc.name());
       }
-    } else if(s.action() == MyMoneySplit::ActionTransfer) {
+    } else if (file->isTransfer(*t)) {
       if(!s.value().isNegative()) {
         txt = i18n("Transfer to %1").arg(acc.name());
       } else {
@@ -680,38 +761,79 @@ void KPayeesView::showTransactions(void)
   QTimer::singleShot(50, this, SLOT(rearrange()));
 }
 
+void KPayeesView::slotKeyListChanged(void)
+{
+  bool rc = false;
+  bool ignorecase = false;
+  QStringList keys;
+  // J.Rodehueser: delete unused variable 'type'
+  // orig:  MyMoneyPayee::payeeMatchType type = m_payee.matchData(ignorecase, keys);
+  m_payee.matchData(ignorecase, keys);
+  if(m_matchType->selectedId() == MyMoneyPayee::matchKey) {
+    rc |= (keys != matchKeyEditList->items());
+  }
+  m_updateButton->setEnabled(rc);
+}
+
 void KPayeesView::slotPayeeDataChanged(void)
 {
   kdDebug(2) << "KPayeesView::slotPayeeDataChanged(void)" << endl;
 
   bool rc = false;
 
-  rc |= ((m_payee.email().isEmpty() != emailEdit->text().isEmpty())
-      || (!emailEdit->text().isEmpty() && m_payee.email() != emailEdit->text()));
-  rc |= ((m_payee.address().isEmpty() != addressEdit->text().isEmpty())
-      || (!addressEdit->text().isEmpty() && m_payee.address() != addressEdit->text()));
-  rc |= ((m_payee.postcode().isEmpty() != postcodeEdit->text().isEmpty())
-      || (!postcodeEdit->text().isEmpty() && m_payee.postcode() != postcodeEdit->text()));
-  rc |= ((m_payee.telephone().isEmpty() != telephoneEdit->text().isEmpty())
-      || (!telephoneEdit->text().isEmpty() && m_payee.telephone() != telephoneEdit->text()));
-  rc |= ((m_payee.name().isEmpty() != m_newName.isEmpty())
-      || (!m_newName.isEmpty() && m_payee.name() != m_newName));
+  if(m_tabWidget->isEnabled()) {
+    rc |= ((m_payee.email().isEmpty() != emailEdit->text().isEmpty())
+        || (!emailEdit->text().isEmpty() && m_payee.email() != emailEdit->text()));
+    rc |= ((m_payee.address().isEmpty() != addressEdit->text().isEmpty())
+        || (!addressEdit->text().isEmpty() && m_payee.address() != addressEdit->text()));
+    rc |= ((m_payee.postcode().isEmpty() != postcodeEdit->text().isEmpty())
+        || (!postcodeEdit->text().isEmpty() && m_payee.postcode() != postcodeEdit->text()));
+    rc |= ((m_payee.telephone().isEmpty() != telephoneEdit->text().isEmpty())
+        || (!telephoneEdit->text().isEmpty() && m_payee.telephone() != telephoneEdit->text()));
+    rc |= ((m_payee.name().isEmpty() != m_newName.isEmpty())
+        || (!m_newName.isEmpty() && m_payee.name() != m_newName));
+    rc |= ((m_payee.notes().isEmpty() != notesEdit->text().isEmpty())
+        || (!notesEdit->text().isEmpty() && m_payee.notes() != notesEdit->text()));
 
-  bool ignorecase = false;
-  QString key;
+    bool ignorecase = false;
+    QStringList keys;
 
-  MyMoneyPayee::payeeMatchType type = m_payee.matchData(ignorecase, key);
-  rc |= (static_cast<int>(type) != m_matchType->selectedId());
+    MyMoneyPayee::payeeMatchType type = m_payee.matchData(ignorecase, keys);
+    rc |= (static_cast<int>(type) != m_matchType->selectedId());
 
-  checkMatchIgnoreCase->setEnabled(false);
-  matchKeyEdit->setEnabled(false);
+    checkMatchIgnoreCase->setEnabled(false);
+    matchKeyEditList->setEnabled(false);
 
-  if(m_matchType->selectedId() != MyMoneyPayee::matchDisabled) {
-    checkMatchIgnoreCase->setEnabled(true);
-    rc |= (ignorecase != checkMatchIgnoreCase->isChecked());
-    if(m_matchType->selectedId() == MyMoneyPayee::matchKey) {
-      matchKeyEdit->setEnabled(true);
-      rc |= (key != matchKeyEdit->text());
+    if(m_matchType->selectedId() != MyMoneyPayee::matchDisabled) {
+      checkMatchIgnoreCase->setEnabled(true);
+      // if we turn matching on, we default to 'ignore case'
+      // TODO maybe make the default a user option
+      if(type == MyMoneyPayee::matchDisabled && m_matchType->selectedId() != MyMoneyPayee::matchDisabled)
+        checkMatchIgnoreCase->setChecked(true);
+      rc |= (ignorecase != checkMatchIgnoreCase->isChecked());
+      if(m_matchType->selectedId() == MyMoneyPayee::matchKey) {
+        matchKeyEditList->setEnabled(true);
+        rc |= (keys != matchKeyEditList->items());
+      }
+    }
+
+    rc |= (checkEnableDefaultAccount->isChecked() != m_payee.defaultAccountEnabled());
+    if (checkEnableDefaultAccount->isChecked()) {
+      comboDefaultAccount->setEnabled(true);
+      labelDefaultAccount->setEnabled(true);
+      // this is only going to understand the first in the list of selected accounts
+      if (comboDefaultAccount->selectedAccounts().empty()) {
+        rc |= !m_payee.defaultAccountId().isEmpty();
+      }
+      else {
+        QString temp = comboDefaultAccount->selectedAccounts().front();
+        rc |= ( temp.isEmpty() != m_payee.defaultAccountId().isEmpty())
+              || (!m_payee.defaultAccountId().isEmpty() && temp != m_payee.defaultAccountId());
+      }
+    }
+    else {
+      comboDefaultAccount->setEnabled(false);
+      labelDefaultAccount->setEnabled(false);
     }
   }
   m_updateButton->setEnabled(rc);
@@ -721,13 +843,24 @@ void KPayeesView::slotUpdatePayee(void)
 {
   if(m_updateButton->isEnabled()) {
     MyMoneyFileTransaction ft;
+    m_updateButton->setEnabled(false);
     try {
       m_payee.setName(m_newName);
       m_payee.setAddress(addressEdit->text());
       m_payee.setPostcode(postcodeEdit->text());
       m_payee.setTelephone(telephoneEdit->text());
       m_payee.setEmail(emailEdit->text());
-      m_payee.setMatchData(static_cast<MyMoneyPayee::payeeMatchType>(m_matchType->selectedId()), checkMatchIgnoreCase->isChecked(), matchKeyEdit->text());
+      m_payee.setNotes(notesEdit->text());
+      m_payee.setMatchData(static_cast<MyMoneyPayee::payeeMatchType>(m_matchType->selectedId()), checkMatchIgnoreCase->isChecked(), matchKeyEditList->items());
+      m_payee.setDefaultAccountId();
+
+      if (checkEnableDefaultAccount->isChecked()) {
+        QString temp;
+        if (!comboDefaultAccount->selectedAccounts().empty()) {
+          temp = comboDefaultAccount->selectedAccounts().front();
+          m_payee.setDefaultAccountId(temp);
+        }
+      }
 
       MyMoneyFile::instance()->modifyPayee(m_payee);
       ft.commit();
@@ -737,7 +870,6 @@ void KPayeesView::slotUpdatePayee(void)
         (e->what() + " " + i18n("thrown in") + " " + e->file()+ ":%1").arg(e->line()));
       delete e;
     }
-    m_updateButton->setEnabled(false);
   }
 }
 
@@ -754,6 +886,10 @@ void KPayeesView::readConfig(void)
 
   m_payeesList->setDefaultRenameAction(
            KMyMoneyGlobalSettings::focusChangeIsEnter() ? QListView::Accept : QListView::Reject);
+
+  //initialize the account list?
+  comboDefaultAccount->loadList((KMyMoneyUtils::categoryTypeE)(KMyMoneyUtils::asset | KMyMoneyUtils::liability | MyMoneyAccount::Income | MyMoneyAccount::Expense));
+
 }
 
 void KPayeesView::show(void)
@@ -800,8 +936,8 @@ void KPayeesView::loadPayees(void)
   if(m_inSelection)
     return;
 
-  QMap<QCString, bool> isSelected;
-  QCString id;
+  QMap<QString, bool> isSelected;
+  QString id;
 
   ::timetrace("Start KPayeesView::loadPayees");
   readConfig();
@@ -850,17 +986,14 @@ void KPayeesView::loadPayees(void)
   // reposition viewport
   m_payeesList->setContentsPos(startPoint.x(), startPoint.y());
 
-#if !KDE_IS_VERSION(3,3,0)
-  // for KDE < 3.3 the list view does not emit signals when new
-  // items are added. Hence we must update the items when they
-  // are loaded manually.
   m_searchWidget->searchLine()->updateSearch(QString::null);
-#endif
 
   // turn updates back on
   m_payeesList->setUpdatesEnabled(true);
   m_payeesList->repaintContents();
 
+  slotSelectPayee();
+
   ::timetrace("End KPayeesView::loadPayees");
 }
 
@@ -892,7 +1025,7 @@ void KPayeesView::slotTransactionDoubleClicked(QListViewItem* i)
     emit transactionSelected(item->accountId(), item->transactionId());
 }
 
-void KPayeesView::slotSelectPayeeAndTransaction(const QCString& payeeId, const QCString& accountId, const QCString& transactionId)
+void KPayeesView::slotSelectPayeeAndTransaction(const QString& payeeId, const QString& accountId, const QString& transactionId)
 {
   if(!isVisible())
     return;
