@@ -122,9 +122,9 @@ void kMyMoneyAccountSelector::setSelectionMode(QListView::SelectionMode mode)
   KMyMoneySelector::setSelectionMode(mode);
 }
 
-const QCStringList kMyMoneyAccountSelector::accountList(const  QValueList<MyMoneyAccount::accountTypeE>& filterList) const
+QStringList kMyMoneyAccountSelector::accountList(const  QValueList<MyMoneyAccount::accountTypeE>& filterList) const
 {
-  QCStringList    list;
+  QStringList    list;
   QListViewItemIterator it;
   QListViewItem* it_v;
   QValueList<MyMoneyAccount::accountTypeE>::ConstIterator it_f;
@@ -200,10 +200,10 @@ bool kMyMoneyAccountSelector::contains(const QString& txt) const
 }
 
 # if 0
-void kMyMoneyAccountSelector::update(const QCString& /* id */)
+void kMyMoneyAccountSelector::update(const QString& /* id */)
 {
   QListViewItem* it_v = m_listView->currentItem();
-  QCString previousHighlighted;
+  QString previousHighlighted;
   bool state = false;
 
   if(m_selMode == QListView::Multi && it_v) {
@@ -216,8 +216,8 @@ void kMyMoneyAccountSelector::update(const QCString& /* id */)
     }
   }
 
-  QCStringList list = selectedAccounts();
-  QCStringList::Iterator it;
+  QStringList list = selectedAccounts();
+  QStringList::Iterator it;
 
   if(!m_typeList.isEmpty())
     loadList(m_typeList);
@@ -245,7 +245,8 @@ void kMyMoneyAccountSelector::update(const QCString& /* id */)
 AccountSet::AccountSet() :
   m_count(0),
   m_file(MyMoneyFile::instance()),
-  m_favorites(0)
+  m_favorites(0),
+  m_hideClosedAccounts(true)
 {
 }
 
@@ -300,14 +301,14 @@ void AccountSet::clear(void)
 
 int AccountSet::load(kMyMoneyAccountSelector* selector)
 {
-  QCStringList list;
-  QCStringList::ConstIterator it_l;
+  QStringList list;
+  QStringList::ConstIterator it_l;
   int count = 0;
   int typeMask = 0;
-  QCString currentId;
+  QString currentId;
 
   if(selector->selectionMode() == QListView::Single) {
-    QCStringList list;
+    QStringList list;
     selector->selectedItems(list);
     if(list.count() > 0)
       currentId = list.first();
@@ -400,18 +401,26 @@ int AccountSet::load(kMyMoneyAccountSelector* selector)
         const MyMoneyAccount& acc = m_file->account(*it_l);
         ++m_count;
         ++count;
-        if(m_typeList.contains(acc.accountType())
-        && !acc.isClosed()) {
+        //this will include an account if it matches the account type and
+        //if it is still open or it has been set to show closed accounts
+        if(includeAccount(acc)
+        && (!isHidingClosedAccounts() || !acc.isClosed()) ) {
           QString tmpKey;
           tmpKey = key + MyMoneyFile::AccountSeperator + acc.name();
           QListViewItem* subItem = selector->newItem(item, acc.name(), tmpKey, acc.id());
-          if(acc.value("PreferredAccount") == "Yes") {
+          if(acc.value("PreferredAccount") == "Yes"
+             && m_typeList.contains(acc.accountType())) {
             selector->newItem(m_favorites, acc.name(), tmpKey, acc.id());
           }
           if(acc.accountList().count() > 0) {
             subItem->setOpen(true);
             count += loadSubAccounts(selector, subItem, tmpKey, acc.accountList());
           }
+
+          //disable the item if it has been added only because a subaccount matches the type
+          if( !m_typeList.contains(acc.accountType()) ) {
+            subItem->setEnabled(false);
+          }
         }
       }
       item->sortChildItems(0, true);
@@ -440,7 +449,7 @@ int AccountSet::load(kMyMoneyAccountSelector* selector)
   return count;
 }
 
-int AccountSet::load(kMyMoneyAccountSelector* selector, const QString& baseName, const QValueList<QCString>& accountIdList, const bool clear)
+int AccountSet::load(kMyMoneyAccountSelector* selector, const QString& baseName, const QValueList<QString>& accountIdList, const bool clear)
 {
   int count = 0;
   QListViewItem* item = 0;
@@ -454,7 +463,7 @@ int AccountSet::load(kMyMoneyAccountSelector* selector, const QString& baseName,
   item = selector->newItem(baseName);
   ++m_count;
 
-  QValueList<QCString>::ConstIterator it;
+  QValueList<QString>::ConstIterator it;
   for(it = accountIdList.begin(); it != accountIdList.end(); ++it)   {
     const MyMoneyAccount& acc = m_file->account(*it);
     if(acc.isClosed())
@@ -477,9 +486,9 @@ int AccountSet::load(kMyMoneyAccountSelector* selector, const QString& baseName,
   return count;
 }
 
-int AccountSet::loadSubAccounts(kMyMoneyAccountSelector* selector, QListViewItem* parent, const QString& key, const QCStringList& list)
+int AccountSet::loadSubAccounts(kMyMoneyAccountSelector* selector, QListViewItem* parent, const QString& key, const QStringList& list)
 {
-  QCStringList::ConstIterator it_l;
+  QStringList::ConstIterator it_l;
   int count = 0;
 
   for(it_l = list.begin(); it_l != list.end(); ++it_l) {
@@ -488,24 +497,48 @@ int AccountSet::loadSubAccounts(kMyMoneyAccountSelector* selector, QListViewItem
     if(acc.isInvest() && !KMyMoneyGlobalSettings::expertMode())
       continue;
 
-    if(m_typeList.contains(acc.accountType())
+    if(includeAccount(acc)
     && !acc.isClosed()) {
       QString tmpKey;
       tmpKey = key + MyMoneyFile::AccountSeperator + acc.name();
       ++count;
       ++m_count;
       QListViewItem* item = selector->newItem(parent, acc.name(), tmpKey, acc.id());
-      if(acc.value("PreferredAccount") == "Yes") {
+      if(acc.value("PreferredAccount") == "Yes"
+         && m_typeList.contains(acc.accountType())) {
         selector->newItem(m_favorites, acc.name(), tmpKey, acc.id());
       }
       if(acc.accountList().count() > 0) {
         item->setOpen(true);
         count += loadSubAccounts(selector, item, tmpKey, acc.accountList());
       }
+
+      //disable the item if it has been added only because a subaccount matches the type
+      if( !m_typeList.contains(acc.accountType()) ) {
+        item->setEnabled(false);
+      }
     }
   }
   return count;
 }
 
+bool AccountSet::includeAccount(const MyMoneyAccount& acc)
+{
+  if( m_typeList.contains(acc.accountType()) )
+    return true;
+
+  QStringList accounts = acc.accountList();
+
+  if(accounts.size() > 0) {
+    QStringList::ConstIterator it_acc;
+    for(it_acc = accounts.begin(); it_acc != accounts.end(); ++it_acc) {
+      MyMoneyAccount account = m_file->account(*it_acc);
+      if( includeAccount(account) )
+        return true;
+    }
+  }
+  return false;
+}
+
 
 #include "kmymoneyaccountselector.moc"
