@@ -93,17 +93,17 @@ public:
   virtual const QString& sortPayee(void) const { return m_payee; }
   virtual const MyMoneyMoney& sortValue(void) const { return m_split.shares(); }
   virtual const QString& sortNumber(void) const { return m_split.number(); }
-  virtual const QCString& sortEntryOrder(void) const { return m_uniqueId; }
+  virtual const QString& sortEntryOrder(void) const { return m_uniqueId; }
   virtual CashFlowDirection sortType(void) const { return m_split.shares().isNegative() ? Payment : Deposit; }
   virtual const QString& sortCategory(void) const { return m_category; }
   virtual MyMoneySplit::reconcileFlagE sortReconcileState(void) const { return m_split.reconcileFlag(); }
 
-  virtual const QCString& id(void) const { return m_uniqueId; }
+  virtual const QString& id(void) const { return m_uniqueId; }
   const MyMoneyTransaction& transaction(void) const { return m_transaction; }
   const MyMoneySplit& split(void) const { return m_split; }
 
-  void setBalance(const QString& balance) { m_balance = balance; }
-  const QString& balance(void) const { return m_balance; }
+  void setBalance(const MyMoneyMoney& balance) { m_balance = balance; }
+  const MyMoneyMoney& balance(void) const { return m_balance; }
 
   virtual int rowHeightHint(void) const;
 
@@ -141,7 +141,7 @@ public:
 
   /**
     * paints a cell of the register for the transaction. Uses paintRegisterCellSetup(), paintRegisterCellText()
-    * paintRegisterGrid() and paintRegisterCellFocus() to actually do the job.
+    * paintRegisterGrid(), paintRegisterIcons() and paintRegisterCellFocus() to actually do the job.
     *
     * @param painter pointer to the QPainter object
     * @param row vertical index of cell in register
@@ -155,6 +155,7 @@ public:
   virtual void paintRegisterCellText(QPainter* painter, int row, int col, const QRect& r, const QColorGroup& cg, int align, const QString& txt);
   virtual void paintRegisterCellBackground(QPainter* painter, int row, int col, const QRect& r, const QBrush& backgroundBrush);
   virtual void paintRegisterGrid(QPainter* painter, int row, int col, const QRect& r, const QColorGroup& cg) const;
+  virtual void paintRegisterIcons(QPainter* painter, int row, int col, const QRect& r, const QColorGroup& cg);
 
   virtual void paintFormCell(QPainter* /* painter */, int /* row */, int /* col */, const QRect& /* r */, bool /* selected */, const QColorGroup& /* cg */);
 
@@ -180,6 +181,8 @@ public:
   virtual void tabOrderInForm(QWidgetList& tabOrderWidgets) const = 0;
   virtual void tabOrderInRegister(QWidgetList& tabOrderWidgets) const = 0;
 
+  virtual KMyMoneyRegister::Action actionType(void) const = 0;
+
   QWidget* focusWidget(QWidget*) const;
   void arrangeWidget(QTable* tbl, int row, int col, QWidget* w) const;
 
@@ -238,6 +241,8 @@ public:
     */
   virtual void setShowRowInForm(int row, bool show) { Q_UNUSED(row); Q_UNUSED(show) }
 
+  virtual void setReducedIntensity(bool reduced) { m_reducedIntensity = reduced; }
+
 protected:
   virtual void markAsErronous(QPainter* p, int row, int col, const QRect& r);
   virtual void markAttachment(QPainter* painter, int row, int col, const QRect& r);
@@ -266,14 +271,14 @@ protected:
   MyMoneyTransaction      m_transaction;
   MyMoneySplit            m_split;
   MyMoneyAccount          m_account;
+  MyMoneyMoney            m_balance;
   QTable*                 m_form;
   QString                 m_category;
   QString                 m_payee;
   QString                 m_payeeHeader;
-  QString                 m_balance;
   QString                 m_categoryHeader;
-  QCString                m_splitCurrencyId;
-  QCString                m_uniqueId;
+  QString                 m_splitCurrencyId;
+  QString                 m_uniqueId;
   int                     m_formRowHeight;
   bool                    m_selected;
   bool                    m_focus;
@@ -281,6 +286,7 @@ protected:
   bool                    m_inEdit;
   bool                    m_inRegisterEdit;
   bool                    m_showBalance;
+  bool                    m_reducedIntensity;
 };
 
 class StdTransaction : public Transaction
@@ -290,7 +296,6 @@ public:
   virtual ~StdTransaction() {}
 
   virtual const char* className(void) { return "StdTransaction"; }
-  virtual void paintRegisterCell(QPainter* painter, int row, int col, const QRect& r, bool selected, const QColorGroup& cg);
 
   bool formCellText(QString& txt, int& align, int row, int col, QPainter* painter = 0);
   void registerCellText(QString& txt, int& align, int row, int col, QPainter* painter = 0);
@@ -305,6 +310,7 @@ public:
   void arrangeWidgetsInRegister(QMap<QString, QWidget*>& editWidgets);
   void tabOrderInForm(QWidgetList& tabOrderWidgets) const;
   void tabOrderInRegister(QWidgetList& tabOrderWidgets) const;
+  KMyMoneyRegister::Action actionType(void) const;
 
   int numRowsRegister(bool expanded) const;
 
@@ -328,7 +334,7 @@ public:
   virtual void setShowRowInForm(int row, bool show);
 
 protected:
-  void setupFormHeader(const QCString& id);
+  void setupFormHeader(const QString& id);
 
 private:
   bool m_showAccountRow;
@@ -362,6 +368,7 @@ public:
   void arrangeWidgetsInRegister(QMap<QString, QWidget*>& editWidgets);
   void tabOrderInForm(QWidgetList& tabOrderWidgets) const;
   void tabOrderInRegister(QWidgetList& tabOrderWidgets) const;
+  KMyMoneyRegister::Action actionType(void) const { return KMyMoneyRegister::ActionNone; }
 
   int numRowsRegister(bool expanded) const;
 
