@@ -42,6 +42,7 @@
 #include <kabc/addressee.h>
 #include <kabc/stdaddressbook.h>
 #include <kmessagebox.h>
+#include <kactivelabel.h>
 
 // ----------------------------------------------------------------------------
 // Project Includes
@@ -170,14 +171,24 @@ GeneralPage::GeneralPage(Wizard* wizard, const char* name) :
   WizardPage<Wizard>(stepCount++, this, wizard, name)
 {
   m_userNameEdit->setFocus();
-  KABC::StdAddressBook *ab = dynamic_cast<KABC::StdAddressBook*>(KABC::StdAddressBook::self());
-  m_loadAddressButton->setEnabled(ab != 0);
+  KABC::StdAddressBook *ab = KABC::StdAddressBook::self(true);
+  connect(ab, SIGNAL(addressBookChanged(AddressBook*)), this, SLOT(slotAddressBookLoaded()));
   connect(m_loadAddressButton, SIGNAL(clicked()), this, SLOT(slotLoadFromKABC()));
+  m_loadAddressButton->setEnabled(false);
+}
+
+void GeneralPage::slotAddressBookLoaded(void)
+{
+  KABC::StdAddressBook *ab = KABC::StdAddressBook::self();
+  if (!ab)
+    return;
+
+  m_loadAddressButton->setEnabled(!ab->whoAmI().isEmpty());
 }
 
 void GeneralPage::slotLoadFromKABC(void)
 {
-  KABC::StdAddressBook *ab = dynamic_cast<KABC::StdAddressBook*>(KABC::StdAddressBook::self());
+  KABC::StdAddressBook *ab = KABC::StdAddressBook::self();
   if (!ab)
     return;
 
@@ -216,10 +227,10 @@ CurrencyPage::CurrencyPage(Wizard* wizard, const char* name) :
   QValueList<MyMoneySecurity> list = MyMoneyFile::instance()->currencyList();
   QValueList<MyMoneySecurity>::const_iterator it;
 
-  QCString localCurrency(localeconv()->int_curr_symbol);
+  QString localCurrency(localeconv()->int_curr_symbol);
   localCurrency.truncate(3);
 
-  QCString baseCurrency = MyMoneyFile::instance()->baseCurrency().id();
+  QString baseCurrency = MyMoneyFile::instance()->baseCurrency().id();
 
   // construct a transparent 16x16 pixmap
   QPixmap empty(16, 16);
@@ -319,11 +330,16 @@ FilePage::FilePage(Wizard* wizard, const char* name) :
   KUser user;
   m_dataFileEdit->setShowLocalProtocol(false);
   m_dataFileEdit->setURL(QString("%1/%2.kmy").arg(QDir::homeDirPath(), user.loginName()));
+
+  // allow selection of non-existing files
+  m_dataFileEdit->setMode(KFile::File);
 }
 
 bool FilePage::isComplete(void) const
 {
   bool rc = m_mandatoryGroup->isEnabled();
+  m_existingFileLabel->hide();
+  m_finishLabel->show();
   if(rc) {
     // if a filename is present, check that
     // a) the file does not exist
@@ -338,6 +354,8 @@ bool FilePage::isComplete(void) const
         }
       }
     }
+    m_existingFileLabel->setHidden(rc);
+    m_finishLabel->setShown(rc);
   }
   return rc;
 }
